//Written for www.HomoFaciens.de
//Coded by Norbert Heinz in 2015
//Version: 0.1
//
//The code was written to create some animation sequences for a video about DC-Motors:
//http://www.homofaciens.de/technics-electric-motors-permanent-magnets_ge_navion.htm
//
//This is a mess of code!!!
//
//
//Created and tested with Ubuntu Linux:
//1.) Get a live and installation DVD of Ubuntu at www.ubuntu.com (if not already installed on your hard disk)
//2.) Open Terminal and install additional components:
//    sudo apt-get install freeglut3 freeglut3-dev
//    To create picture sequences:
//    sudo apt-get install imagemagick
//
//3.) Compile with: gcc DC-Motor.c -lglut -lGLU -lGL -lX11 -lXxf86vm -o DC-Motor
//4.) Run with: ./DC-Motor 1 10 0
//
//      Example of usage: ./DC-Motor 3 10 0
//      First integer dials the animation sequence (1-12)
//      Second integer sets slow down factor of animation in milliseconds(0-10000)
//      If third integer is greater than 0, pictures are stored in folder animation_XX, starting with picture number given.
//      
//      When animation is running:
//      Space: Stop/Start
//      +: Zoom in
//      -: Zoom out
//      u: move up
//      d: move down
//      cursor: rotate
//      up/down key: rotate
//      F2: take snapshot
//      F1: change between window mode and fullscreen
//
//This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free
//Software Foundation version 3 of the License.
//
//This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License along with this program; if not, see http://www.gnu.org/licenses/.
//
 
#include <stdio.h>
#include <stdlib.h>
#include <GL/glx.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include <X11/extensions/xf86vmode.h>
#include <X11/keysym.h>
#include <math.h>           /* for the sin() function */
#include <string.h>

#define CHARACTERS 256            //Number of characters
#define PI 3.1415927f
#define PATHMAX 20
#define MAGNETMAX 10


GLfloat SchriftFarbe[6];
GLfloat HGFarbe[3]={0.0f, 0.0f, 0.0f};
char SavePath[1000];

int gridX = 64;
int gridY = 32;
GLfloat GRIDDIVISOR = 5.0f;
GLfloat SCALE = 0.1f;
GLfloat ArrowZ = 4.5f;

int slowDownMS = 0;
int animationPause = 0;
int temp = 0;
int animation = 0;
int animationStep = 0;
int animationFrames = 0;
int picNumber = 0;
int firstStart = 10;
int paintLastPic = 0;
int contactFrames = 0;

double doubleTemp = 0.0;
GLfloat GLfloatTemp = 0.0f;

int enableLight1 = 1, enableLight2 = 1, enableLight3 = 1;
int startPicNumber = 0;

int pauseFrames = 0;

int positron[10000];
int positron2[10000];
int positron3[10000];
int lastPositronActive = 0;
int lastPositronActive2 = 0;
int lastPositronActive3 = 0;
int positronStep = 1;
int paintPath = 0;
int paintPath2 = 0;


int isCommutatorContact = False;
int isCommutatorContact2 = False;
int isCommutatorContact3 = False;
int enableBattery1 = False;
int enableBattery2 = False;
int enablePositrons = False;
int enablePositronMovement = False;
int enablePositronMovement2 = False;
int enablePositronMovement3 = False;
int enableMagnet[10];
int enableSwapMagnet[10];
int enableSwapPolarity = False;
int enableSwapPolarity2 = False;
int enableSwapPolarity3 = False;
int enableBluePositrons = False;
int enableBlueWire = False;
int enableGoldenWire = False;
int enableWhitePositrons = False;
int enableMotorRot = False;
int enableAxis = False;
int enableOrtho = False;
int enableCommutator = False;
int enablePath2 = False;
int enablePath3 = False;
int enableSwapMotor = False;
int enablePositronsAll = True;
int enablePositronMovementAll = True;
int enableMagnetsAll = True;


GLfloat path[100000][6];
GLfloat path2[100000][6];
GLfloat path3[100000][6];
int pathNumber = 0;
int pathNumber2 = 0;
int pathNumber3 = 0;
GLfloat scratch[100000][6];
int scratchNumber = 0;
GLfloat pathCorners[100][3];
GLfloat pathCorners2[100][3];
GLfloat pathCorners3[100][3];
int maxPathCorners = 5;
GLfloat pathStep = 0.025;
int positronPlusPos = 0;
int positronMinusPos = 0;

GLfloat radius=2.0f;
GLfloat Bat1X1=4.0f, Bat1Y1=2.0f, Bat1Z1=-0.5f;
GLfloat Bat1X2=4.0f, Bat1Y2=2.0f, Bat1Z2=0.5f;
GLfloat Bat2X1=4.0f, Bat2Y1=2.0f, Bat2Z1=-0.5f;
GLfloat Bat2X2=4.0f, Bat2Y2=2.0f, Bat2Z2=0.5f;
GLfloat MotorRotX = 0.0f;
GLfloat MotorRotSpeed = 0.1f;
GLfloat MotorRotSpeedOld = 0.0f;
GLfloat MagnetX[MAGNETMAX], MagnetY[MAGNETMAX], MagnetZ[MAGNETMAX], MagnetD[MAGNETMAX], MagnetL[MAGNETMAX], MagnetRot[MAGNETMAX];

GLuint base;            /* base display list for the font */

GLfloat planeColor[] = {1.0, 1.0, 1.0}; 
GLfloat axeXColor[] = {1.0, 0.0, 1.0}; 
GLfloat axeYColor[] = {0.0, 1.0, 1.0}; 
GLfloat axeZColor[] = {1.0, 1.0, 0.0}; 


GLfloat redMaterial[] = {1.0, 0.0, 0.0}; 
GLfloat blueMaterial[] = {0.0, 0.0, 1.0};
GLfloat greenMaterial[] = {0.0, 1.0, 0.0}; 
GLfloat orangeMaterial[] = {1.0, 0.0, 1.0}; 

GLfloat lightWhite1[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat lightBlack1[] = { 0.0f, 0.0f, 0.0f, 0.0f };
GLfloat lightGrey1[] = { 0.5f, 0.5f, 0.5f, 1.0f };
GLfloat lightRed1[] = { 1.0f, 0.0f, 0.0f, 1.0f };
GLfloat lightRed2[] = { 0.7f, 0.0f, 0.0f, 0.50f };
GLfloat lightRed3[] = { 1.0f, 0.6f, 0.6f, 0.50f };
GLfloat lightGreen1[] = { 0.0f, 1.0f, 0.0f, 1.0f };
GLfloat lightBlue1[] = { 0.0f, 0.7f, 1.0f, 1.0f };
GLfloat lightBlue2[] = { 0.75f, 1.0f, 1.0f, 1.0f };
GLfloat lightBlue3[] = { 0.0f, 0.4f, 1.0f, 1.0f };
GLfloat lightMagenta1[] = { 1.0f, 0.0f, 1.0f, 1.0f };
GLfloat lightMagenta2[] = { 1.0f, 0.75f, 1.0f, 1.0f };
GLfloat lightYellow1[] = { 1.0f, 1.0f, 0.0f, 1.0f };
GLfloat lightGolden1[] = { 1.0f, 0.5f, 0.0f, 1.0f };
GLfloat lightOrange1[] = { 1.0f, 0.7f, 0.0f, 1.0f };
GLfloat lightOrange2[] = { 0.7f, 0.5f, 0.0f, 0.50f };
GLfloat lightSpecularOrange1[] = { 0.5f, 0.35f, 0.0f, 0.3f };

GLfloat lightTemp[] = { 1.0f, 0.0f, 0.0f, 1.0f };

GLfloat lightPosition0[] = { -5.0f, -2.0f, 5.0f, 1.0f };

GLfloat specular1[] = { 1.0f, 1.0f, 1.0f, 1.0f}; 
GLfloat lightSpot1[] = { 0.3f, 0.3f, 0.3f, 0.3f}; 
GLfloat lightAmbient1[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat lightDiffuse1[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat lightPosition1[] = { -5.0f, 2.0f, 5.0f, 1.0f };

GLfloat specular2[] = { 1.0f, 1.0f, 1.0f, 0.3f}; 
GLfloat lightSpot2[] = { 0.3f, 0.3f, 0.3f, 0.3f}; 
GLfloat lightAmbient2[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat lightDiffuse2[] = { 0.3f, 0.3f, 0.3f, 0.5f };
GLfloat lightPosition2[] = { 0.0f, 2.0f, 10.0f, 1.0f };

GLfloat specular3[] = { 1.0f, 1.0f, 1.0f, 0.3f}; 
GLfloat lightSpot3[] = { 0.3f, 0.3f, 0.3f, 0.3f}; 
GLfloat lightAmbient3[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat lightDiffuse3[] = { 0.3f, 0.3f, 0.3f, 0.5f };
GLfloat lightPosition3[] = { 2.0f, 2.0f, 10.0f, 1.0f };

GLfloat white[] = { 1.0f, 1.0f, 1.0f, 1.0f };
GLfloat red[] = { 1.0f, 0.0f, 0.0f, 1.0f };

GLfloat normalVector[] = { 1.0f, 1.0f, 1.0f };
GLfloat p1[] = { 1.0f, 1.0f, 1.0f };
GLfloat p2[] = { 1.0f, 1.0f, 1.0f };
GLfloat p3[] = { 1.0f, 1.0f, 1.0f };
GLfloat p4[] = { 1.0f, 1.0f, 1.0f };

/* stuff about our window grouped together */
typedef struct {
    Display *dpy;
    int screen;
    Window win;
    GLXContext ctx;
    XSetWindowAttributes attr;
    Bool fs;
    XF86VidModeModeInfo deskMode;
    int x, y;
    unsigned int width, height;
    unsigned int depth;    
} GLWindow;

typedef struct {
    int width;
    int height;
    unsigned char *data;
} textureImage;

/* attributes for a single buffered visual in RGBA format with at least
 * 4 bits per color and a 16 bit depth buffer */
static int attrListSgl[] = {GLX_RGBA, GLX_RED_SIZE, 4, 
    GLX_GREEN_SIZE, 4, 
    GLX_BLUE_SIZE, 4, 
    GLX_DEPTH_SIZE, 16,
    None};

/* attributes for a double buffered visual in RGBA format with at least
 * 4 bits per color and a 16 bit depth buffer */
static int attrListDbl[] = { GLX_RGBA, GLX_DOUBLEBUFFER, 
    GLX_RED_SIZE, 4, 
    GLX_GREEN_SIZE, 4, 
    GLX_BLUE_SIZE, 4, 
    GLX_DEPTH_SIZE, 16,
    None };

GLWindow GLWin;
Bool done;
GLfloat hold;               /* temporary variable */
GLfloat rotX;  /* X Rotation */
GLfloat rotY;  /* Y Rotation */
GLfloat rotZ;  /* Z Rotation */

GLfloat translateZ = 0.0f;
GLfloat translateX = 0.0f;
GLfloat translateY = 0.0f;

GLfloat rotXdiff;  /* X Rotation */
GLfloat rotYdiff;  /* Y Rotation */
GLfloat rotZdiff;  /* Z Rotation */
GLfloat translateZdiff = 0.0f;
GLfloat translateXdiff = 0.0f;
GLfloat translateYdiff = 0.0f;

GLfloat rotXtarget;
GLfloat rotYtarget;
GLfloat rotZtarget;
GLfloat translateZtarget = 0.0f;
GLfloat translateXtarget = 0.0f;
GLfloat translateYtarget = 0.0f;
GLfloat transitionFrames = 0.0f;



GLuint  textureFont[512 + 10];  /* Storage For One Texture */
int TextureImageX, TextureImageY;


//+++++++++++++ Loads A Bitmap Image +++++++++++++++++++++++++++++++
unsigned char *LoadBMP(char *Filename){

  FILE *File=NULL;                                // File Handle
  char FilenameLanguage[1000];
  unsigned char *ImageData;
  unsigned short int bfType;
  long int bfOffBits;
  short int biPlanes;
  short int biBitCount;
  long int biSizeImage;
  int i;
  unsigned char temp;

  if (!Filename)                                  // Make Sure A Filename Was Given
  {
    return NULL;                                  // If Not Return NULL
  }


  /* make sure the file is there and open it read-only (binary) */
  if ((File = fopen(Filename, "rb")) == NULL){
    printf("File not found : %s\n", Filename);
    return NULL;
  }
  if(!fread(&bfType, sizeof(short int), 1, File)){
    printf("Error reading : %s\n", Filename);
    return NULL;
  }
  /* check if file is a bitmap */
  if (bfType != 19778){
    printf("No bitmap-format! : %s\n", Filename);
    return NULL;
  }
  /* get the file size */
  /* skip file size and reserved fields of bitmap file header */
  fseek(File, 8, SEEK_CUR);
  /* get the position of the actual bitmap data */
  if (!fread(&bfOffBits, sizeof(long int), 1, File)){
    printf("Error reading OffBits : %s\n", Filename);
    return NULL;
  }
  //printf("Data at Offset: %ld\n", bfOffBits);
  /* skip size of bitmap info header */
  fseek(File, 4, SEEK_CUR);
  /* get the width of the bitmap */
  fread(&TextureImageX, sizeof(int), 1, File);
  //printf("Width of Bitmap: %d\n", texture->width);
  /* get the height of the bitmap */
  fread(&TextureImageY, sizeof(int), 1, File);
  //printf("Height of Bitmap: %d\n", texture->height);
  /* get the number of planes (must be set to 1) */
  fread(&biPlanes, sizeof(short int), 1, File);
  if (biPlanes != 1){
    printf("Wrong BiPlane : %s\n", Filename);
    return NULL;
  }
  /* get the number of bits per pixel */
  if (!fread(&biBitCount, sizeof(short int), 1, File)){
    printf("Wrong BitCount : %s\n", Filename);
    return NULL;
  }
  //printf("Bits per Pixel: %d\n", biBitCount);
  if (biBitCount != 24){
    printf("Wrong depth : %s\n", Filename);
    return NULL;
  }
  /* calculate the size of the image in bytes */
  biSizeImage = TextureImageX * TextureImageY * 3;
  //printf("Size of the image data: %ld\n", biSizeImage);
  if((ImageData = (unsigned char*)malloc(biSizeImage))==NULL){
    printf("Could not allocate memory for %s\n", Filename);
    return NULL;
  }
  /* seek to the actual data */
  fseek(File, bfOffBits, SEEK_SET);
  if (!fread(ImageData, biSizeImage, 1, File)){
    printf("Error reading data : %s\n", Filename);
    return NULL;
  }
  /* swap red and blue (bgr -> rgb) */
  for (i = 0; i < biSizeImage; i += 3){
    temp = ImageData[i];
    ImageData[i] = ImageData[i + 2];
    ImageData[i + 2] = temp;
  }

  fclose(File);

  return ImageData;   // If Load Failed Return 0
}//-------------------------------------------------------------------------- Loads A Bitmap Image -------------------------


//++++++++++++++++++++++++++++++++++++++++ Load Fonts And Convert To Textures +++++++++++++++++++++++++++++++++++++
int LoadFonts(){
  int i, i2, i3;
  int FarbInvers;
  float StartZeit, EndZeit;
  int SchwarzerSchirm=False;
  int AnzeigeEnde=False;
  char Taste;
  char DateiName[1000];
  unsigned char *TextureImageData;


  for(i = 0; i < CHARACTERS; i++){// Loop Through All CHARACTERS Textures
    sprintf(DateiName, "Data/font_%03d.bmp", i);
    if ((TextureImageData = LoadBMP(DateiName))==NULL){
      printf("Could not load %s", DateiName);
      done=True;
      return False;
    }

    //printf("Loading %s, TextureImageX=%d, TextureImageY=%d\n", DateiName, TextureImageX, TextureImageX);

    for(i2 = 0; i2 < TextureImageX * TextureImageY * 3; i2++){
      FarbInvers = TextureImageData[i2];
      if(FarbInvers<0){
        printf("FarbInvers=%d", FarbInvers);
      }
      FarbInvers-=255;
      FarbInvers=-FarbInvers;
      TextureImageData[i2]=(char)FarbInvers;
    }

    glGenTextures(1, &textureFont[i]);
    glBindTexture(GL_TEXTURE_2D, textureFont[i]);
    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
    glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImageX, TextureImageY, 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImageData);

    //Zugehoerige Maske generieren
    for(i2 = 0; i2 < TextureImageX * TextureImageY * 3; i2++){
      FarbInvers = TextureImageData[i2];
      if(FarbInvers < 0){
        printf("FarbInvers=%d", FarbInvers);
      }
      FarbInvers -= 255;
      FarbInvers = -FarbInvers;
      TextureImageData[i2]=(unsigned char)FarbInvers;
    }

    glGenTextures(1, &textureFont[256 + i]);
    glBindTexture(GL_TEXTURE_2D, textureFont[256 + i]);
    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
    glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImageX, TextureImageY, 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImageData);

    if (TextureImageData!=NULL){    // If Texture Image Exists
      free(TextureImageData); // Free The Texture Image Memory
    }

    if(done)return False;
  }//for(i = 0; i < CHARACTERS; i++)


  return True;                                // Return The Status
}//----------------------------------------------------------------- Ende Load Fonts ------------------------------------------



//+++++++++++++++++++++++++++++++++ 2D text with OpenGL +++++++++++++++++++
void printGLf(GLfloat x, GLfloat y, const char *stringToPrint, int center, int fontColor, GLfloat Size){
GLfloat BreiteF, HoeheF;
unsigned int i, b;


  glPushMatrix();

  BreiteF = Size;
  HoeheF = 0.09f / 0.055f * Size;
  
  glDisable(GL_LIGHTING);
  
  //printf("printGLf: >%s< BreiteF=%lf, HoeheF=%lf\n", stringToPrint, BreiteF, HoeheF);

  if(center == 1){
    x=-1.0f * strlen(stringToPrint) * BreiteF;
  }
  if (strlen(stringToPrint) > 0){
    for(i=0;i<strlen(stringToPrint);i++){
      b=(unsigned int)(stringToPrint[i]);
      //printf("b=%d\n", b);
      //if(string[i]=='Ä')b=196;
      //if(string[i]=='Ö')b=214;
      //if(string[i]=='Ü')b=220;
      //if(string[i]=='ä')b=228;
      //if(string[i]=='ö')b=246;
      //if(string[i]=='ü')b=252;
      //if(string[i]=='ß')b=223;
      //if(string[i]=='´')b=146;
      if(b > 0 && b < 256){
        if(fontColor < 0){//Black Background color if fontcolor < 0
          glColor3f(0.0f, 0.0f, 0.0f);
        }
        else{
          glColor3f(1.0f, 1.0f, 1.0f);
        }
        glEnable(GL_TEXTURE_2D);
        glEnable(GL_BLEND);
        glBlendFunc(GL_DST_COLOR, GL_ZERO);
        glLoadIdentity();
        glTranslatef((float)(x + i * BreiteF * 2.0f), y, -6.0f);
        glBindTexture(GL_TEXTURE_2D, textureFont[256 + b]);
        
        glBegin(GL_QUADS);
            glTexCoord2f(0.0f, 1.0f);
            glVertex3f(-BreiteF, HoeheF, 0.0f);
            glTexCoord2f(1.0f, 1.0f);
            glVertex3f(BreiteF, HoeheF, 0.0f);
            glTexCoord2f(1.0f, 0.0f);
            glVertex3f(BreiteF, -HoeheF, 0.0f);
            glTexCoord2f(0.0f, 0.0f);
            glVertex3f(-BreiteF, -HoeheF, 0.0f);
        glEnd();


        glColor3f(1.0f, 1.0f, 0.0f);//Yellow is the standard
        if(fontColor == 1 || fontColor == -1){
          glColor3f(0.0f, 1.0f, 0.0f);
        }
        if(fontColor == 2 || fontColor == -2){//Orange
          glColor3f(1.0f, 0.75f, 0.0f);
        }
        if(fontColor == 3 || fontColor == -3){//Red
          glColor3f(1.0f, 0.0f, 0.0f);
        }
        if(fontColor == 4 || fontColor == -4){
          glColor3f(0.0f, 1.0f, 1.0f);
        }
        if(fontColor == 5 || fontColor == -5){//Yellow
          glColor3f(1.0f, 1.0f, 0.0f);
        }
        if(fontColor == 6 || fontColor == -6){//Light blue
          glColor3f(0.0f, 0.7f, 1.0f);
        }

        glBlendFunc(GL_ONE, GL_ONE);
        glBindTexture(GL_TEXTURE_2D, textureFont[b]);
        glBegin(GL_QUADS);
            glTexCoord2f(0.0f, 1.0f);
            glVertex3f(-BreiteF, HoeheF, 0.0f);
            glTexCoord2f(1.0f, 1.0f);
            glVertex3f(BreiteF, HoeheF, 0.0f);
            glTexCoord2f(1.0f, 0.0f);
            glVertex3f(BreiteF, -HoeheF, 0.0f);
            glTexCoord2f(0.0f, 0.0f);
            glVertex3f(-BreiteF, -HoeheF, 0.0f);
        glEnd();

      }
    }
    glColor3f(1.0f, 1.0f, 1.0f);
  }
  
  glPopMatrix();


}//----------------------------------------------------------------------------- Ende Textausgabe mit OpenGL ---------------------

/* function called when our window is resized (should only happen in window mode) */
void resizeGLScene(unsigned int width, unsigned int height){
    if (height == 0)    /* Prevent A Divide By Zero If The Window Is Too Small */
        height = 1;
    /* Reset The Current Viewport And Perspective Transformation */
    glViewport(0, 0, width, height);
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    gluPerspective(45.0f, (GLfloat)width / (GLfloat)height, 0.1f, 100.0f);
    //glFrustum (-1.0, 1.0, -1.0, 1.0, 1.5, 20.0);
    if(enableOrtho){
      glOrtho(-4.0, 4.0, -4.0, 4.0, 5, 100);
    }
    glMatrixMode(GL_MODELVIEW);
}



int screenshotTest(){
  int Xres = 1920, Yres = 1080;
  unsigned int i;
  long result=0;
  char fileName[1000];
  char picNumberChar[1000];
  
	static unsigned char header[54] = {
		0x42, 0x4D, 0x36, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x36, 0x00, 0x00, 0x00, 0x28, 0x00, 
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x18, 0x00, 0x00, 0x00, 
		0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0xC4, 0x0E, 0x00, 0x00, 0xC4, 0x0E, 0x00, 0x00, 0x00, 0x00, 
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
 
	unsigned char *pixels = (unsigned char *) malloc(Xres * Yres * 3);
	((uint16_t *) header)[ 9] = Xres;
	((uint16_t *) header)[11] = Yres;
 
	glReadPixels(0,0,Xres,Yres,GL_RGB,GL_UNSIGNED_BYTE,pixels);
 
	unsigned char temp;
	for ( i = 0; i < Xres * Yres * 3; i += 3){
		temp = pixels[i];
		pixels[i] = pixels[i + 2];
		pixels[i + 2] = temp;
	}
 
	FILE *saveFile = NULL;
	unsigned long Size;
 
  strcpy(fileName, "./PicSequence/pic_");
  sprintf(picNumberChar, "%05d.bmp", picNumber);
  strcat(fileName, picNumberChar);
 
  if ((saveFile = fopen(fileName, "w+b")) == NULL){
      printf("File not opened for writing!\n");
      return 1;
  }
 
 
  result = fwrite(header, 54, 1, saveFile);
  if(result < 1){
    printf("Error writing header to file ImageData.bmp! Bytes written = %ld\n", result);
    return 1;
  }    
 
  result = fwrite(pixels, 3 * Xres * Yres, 1, saveFile);
  
  if(result < 1){
    printf("Error writing file ImageData.bmp! Bytes written = %ld\n", result);
    return 1;
  }    
  
  fclose(saveFile);
  
  free(pixels);
 
  picNumber++;
 
  return 0;
}



int ScreenShot(){  
  char fileName[1000];
  char fileName2[1000];
  char picNumberChar[1000];
  char commandLine[1000];

   
  // GLubyte * bits; //RGB bits  
  GLint viewport[4]; //current viewport  
    
  //get current viewport  
  glGetIntegerv(GL_VIEWPORT, viewport);  
  
  uint32_t screenWidth = viewport[2];  
  uint32_t screenHeight = viewport[3];  
  int i, j;
  FILE *saveFile;
  uint32_t BMsize;
  uint32_t tempLong = 0;
  uint16_t tempInt = 0;
  uint32_t BMoffset;
  uint32_t BMheaderSize;
  unsigned char tempChar;
  unsigned char *buffer = (unsigned char *) malloc(screenWidth * screenHeight * 3);

  printf("Starting screenshot.\n", fileName);
   
//  GLubyte bits[3*w*h];
  
  //read pixel from frame buffer  
  glFinish(); //finish all commands of OpenGL  
  glPixelStorei(GL_PACK_ALIGNMENT,1); //or glPixelStorei(GL_PACK_ALIGNMENT,4);  
  glPixelStorei(GL_PACK_ROW_LENGTH, 0);  
  glPixelStorei(GL_PACK_SKIP_ROWS, 0);  
  glPixelStorei(GL_PACK_SKIP_PIXELS, 0);  
    
  //buffer = (GLubyte *)malloc(screenWidth * screenHeight * 3);  
  
  glReadPixels(0, 0, screenWidth, screenHeight, GL_RGB, GL_UNSIGNED_BYTE, buffer);  
  
  printf("Width=%d, height=%d\n", screenWidth, screenHeight);
  
	for ( i = 0; i < screenWidth * screenHeight * 3; i += 3){
		tempChar = buffer[i];
		buffer[i] = buffer[i + 2];
		buffer[i + 2] = tempChar;
	}
  
  
  strcpy(fileName, SavePath);
  strcat(fileName, "/pic_");
  sprintf(picNumberChar, "%05d.bmp", picNumber);
  strcat(fileName, picNumberChar);

  strcpy(fileName2, SavePath);
  strcat(fileName2, "/pic_");
  sprintf(picNumberChar, "%05d.jpg", picNumber);
  strcat(fileName2, picNumberChar);
  
  if ((saveFile = fopen(fileName, "w+b")) == NULL){
      //printf("Highscores not opened for writing: %s\n", filename);
      return 1;
  }
  else{
    printf("%s opened.\n", fileName);
  }
  
  //IplImage * capImg = cvCreateImage( cvSize(w,h), IPL_DEPTH_8U, 3);  
  
  fwrite("BM", 2, 1, saveFile);
  BMsize = screenWidth * screenHeight * 3 + 54;
  fwrite(&BMsize, 4, 1, saveFile);
  tempLong = 0;
  fwrite(&tempLong, 4, 1, saveFile);
  BMoffset = 54;
  fwrite(&BMoffset, 4, 1, saveFile);
  BMheaderSize = 40;
  fwrite(&BMheaderSize, 4, 1, saveFile);
  fwrite(&screenWidth, 4, 1, saveFile);
  fwrite(&screenHeight, 4, 1, saveFile);
  tempInt = 1;
  fwrite(&tempInt, 2, 1, saveFile);
  tempInt = 3 * 8;
  fwrite(&tempInt, 2, 1, saveFile);
  tempLong = 0;
  fwrite(&tempLong, 4, 1, saveFile);
  tempLong = 3 * screenWidth * screenHeight;
  fwrite(&tempLong, 4, 1, saveFile);
  tempLong = 0;
  fwrite(&tempLong, 4, 1, saveFile);
  tempLong = 0;
  fwrite(&tempLong, 4, 1, saveFile);
  tempLong = 0;
  fwrite(&tempLong, 4, 1, saveFile);
  tempLong = 0;
  fwrite(&tempInt, 4, 1, saveFile);
  
  printf("Writing buffer to file.\n");
  
  if(!fwrite(buffer, 3 * screenWidth * screenHeight, 1, saveFile)){
    printf("Error writing file ImageData.bmp!\n");
    return 1;
  }    
  
  fclose(saveFile);
  
  free(buffer);
  
  printf("%s saved.\n", fileName);
  
  strcpy(commandLine, "convert ");
  strcat(commandLine, fileName);
  strcat(commandLine, " -quality 90 ");
  strcat(commandLine, fileName2);
  printf("executing %s...\n", commandLine);
  system(commandLine);
  strcpy(commandLine, "rm ");
  strcat(commandLine, fileName);
  system(commandLine);
  printf("...done.\n");

  picNumber++;
  
  return 0;
   
}  


/* general OpenGL initialization function */
int initGL(GLvoid){
    int x, y;
    float chargeX = gridX / 2.0f, chargeY = gridY / 2.0f;
    float totalDistance = 0.0f, totalForce = 0.0f;

    printf("Loading fonts...\n");
    if (!LoadFonts())                // Jump To Texture Loading Routine
    {
      return False;                        // If Texture Didn't Load Return False
    }
    else{
      printf("Fonts OK.\n");
    }


    glEnable(GL_TEXTURE_2D);       /* Enable Texture Mapping */
    glShadeModel(GL_SMOOTH);
    
    glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
    glClearDepth(1.0f);
    glHint(GL_LINE_SMOOTH_HINT, GL_NICEST);
    glEnable(GL_LINE_SMOOTH);
    glEnable(GL_DEPTH_TEST);
    glDepthFunc(GL_LEQUAL);
    glBlendFunc(GL_SRC_ALPHA, GL_ONE);
    glShadeModel(GL_SMOOTH);
    glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
    //glPolygonMode(GL_BACK, GL_FILL);
    glPolygonMode(GL_BACK, GL_LINE);
    glPolygonMode(GL_FRONT, GL_LINE);

    //glColor4f(1.0f, 1.0f, 1.0f, 0.9f);  /* full brightness, 50% Alpha */


    glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, white);
    glMaterialf(GL_FRONT_AND_BACK, GL_SHININESS, 80.0f);

    glLightfv(GL_LIGHT0, GL_AMBIENT, lightAmbient1);
    glLightfv(GL_LIGHT0, GL_DIFFUSE, lightDiffuse1);
    glLightfv(GL_LIGHT0, GL_POSITION, lightPosition0);
    //glLightfv(GL_LIGHT0,GL_SPECULAR,specular1);
//    glEnable(GL_LIGHT0);


    glLightfv(GL_LIGHT1, GL_AMBIENT, lightAmbient1);
    glLightfv(GL_LIGHT1, GL_DIFFUSE, lightDiffuse1);
    glLightfv(GL_LIGHT1, GL_POSITION, lightPosition1);
    glLightfv(GL_LIGHT1,GL_SPECULAR,specular1);
    glEnable(GL_LIGHT1);

    //glLightfv(GL_LIGHT2, GL_AMBIENT, lightAmbient2);
    glLightfv(GL_LIGHT2, GL_DIFFUSE, lightDiffuse2);
    //glLightfv(GL_LIGHT2, GL_POSITION, lightPosition2);
    //glLightfv(GL_LIGHT2,GL_SPECULAR,specular2);
//    glEnable(GL_LIGHT2);
    
    //glLightfv(GL_LIGHT3, GL_AMBIENT, lightAmbient3);
    glLightfv(GL_LIGHT3, GL_DIFFUSE, lightDiffuse3);
    //glLightfv(GL_LIGHT3, GL_POSITION, lightPosition3);
    //glLightfv(GL_LIGHT3,GL_SPECULAR,specular3);
//    glEnable(GL_LIGHT3);
    
    glEnable(GL_LIGHTING);
    
    //glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
    
    //glEnable(GL_BLEND);
    
    /* we use resizeGLScene once to set up our initial perspective */
    resizeGLScene(GLWin.width, GLWin.height);
    glFlush();
    return True;
}


void calculateNormalVector(){
  GLfloat length;
  
  GLfloat p2minp1[3];
  GLfloat p3minp1[3];
 
  p2minp1[0] = p2[0] - p1[0];
  p2minp1[1] = p2[1] - p1[1];
  p2minp1[2] = p2[2] - p1[2];
  
  p3minp1[0] = -(p3[0] - p1[0]);
  p3minp1[1] = -(p3[1] - p1[1]);
  p3minp1[2] = -(p3[2] - p1[2]);
  
  
  //Normalize Z-component to 1.0f for maximum reflection
  
  normalVector[0] = p2minp1[1] * p3minp1[2] - p2minp1[2] * p3minp1[1];
  normalVector[1] = p2minp1[2] * p3minp1[0] - p2minp1[0] * p3minp1[2];
  normalVector[2] = p2minp1[0] * p3minp1[1] - p2minp1[1] * p3minp1[0];
  
  length = sqrt(pow(normalVector[0], 2.0) + pow(normalVector[1], 2.0) + pow(normalVector[2], 2.0));

  normalVector[0] = normalVector[0] / length;
  normalVector[1] = normalVector[1] / length;
  normalVector[2] = normalVector[2] / length;
  
  //normalVector[2] = 1.0;
  
//  if(normalVector[2] < 0.0f){
//    normalVector[2] = -normalVector[2];
//  }
  
}

//++++++++++++++++++++++++++++++++++ Draw sphere ++++++++++++++++++++++++++++++++++++++++++++++++++
void drawSphere(GLfloat x1, GLfloat y1, GLfloat z1, double radius, int nSlice, int nStack, int enableTranslucentSphere){
    int i, j;
    double phi; //
    double theta; //long
    float sp[129][129][3]; //Vertex
    float *sp1,*sp2,*sp3,*sp4;
    float spn[129][129][3]; //Vertex
    float *spn1,*spn2,*spn3,*spn4;




  glPushMatrix();
  glTranslatef( x1,y1,z1 );  

  if(enableTranslucentSphere == 1){
//    glPolygonMode(GL_FRONT, GL_LINE);
//    glPolygonMode(GL_BACK, GL_LINE);
//    glRotatef(90.0f, 0.0f, 1.0f, 0.0f);  /* rotate on the X axis */

    glBlendFunc(GL_SRC_ALPHA,GL_ONE);
    //glBlendFunc(GL_ONE ,GL_SRC_ALPHA);
    //glBlendFunc(GL_DST_COLOR, GL_ZERO);
    //glBlendFunc(GL_DST_COLOR, GL_ONE);
    //glBlendFunc(GL_ONE, GL_ONE);
    //glBlendFunc(GL_SRC_ALPHA,GL_ZERO);
    //glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
    //glBlendFunc(GL_SRC_COLOR, GL_DST_ALPHA);
    
    glEnable(GL_BLEND);
    glDisable(GL_DEPTH_TEST);
    //glEnable(GL_COLOR_MATERIAL);
    //glDisable(GL_LIGHTING);
    glColor4f(0.2f,0.2f,0.2f,0.1f); 

  }

  

    if(nSlice > 128) nSlice = 128;
    if(nStack > 128) nStack = 128;

    //Vertex
    for(i = 0;i <= nSlice;i++){   
        phi = 2.0 * M_PI * (double)i / (double)nSlice;
        for(j = 0;j <= nStack;j++){   
            theta = M_PI * (double)j / (double)nStack;
            sp[i][j][0] = (float)(radius * sin(theta) * cos(phi));//x
            sp[i][j][1] = (float)(radius * sin(theta) * sin(phi));//y
            sp[i][j][2] = (float)(radius * cos(theta));           //z
        }
    }

    //Normals (radius = 1);
    for(i = 0;i <= nSlice;i++){   
        phi = 2.0 * M_PI * (double)i / (double)nSlice;
        for(j = 0;j <= nStack;j++){   
            theta = M_PI * (double)j / (double)nStack;
            spn[i][j][0] = (float)(1.0 * sin(theta) * cos(phi));//x
            spn[i][j][1] = (float)(1.0 * sin(theta) * sin(phi));//y
            spn[i][j][2] = (float)(1.0 * cos(theta));           //z
        }
    }


    //Top(j=0)
    for(i = 0;i < nSlice; i++){
        sp1 = sp[i][0];
        sp2 = sp[i][1];
        sp3 = sp[i+1][1]; 

        spn1 = spn[i][0];
        spn2 = spn[i][1];
        spn3 = spn[i+1][1]; 

        glBegin(GL_TRIANGLES);            
            glNormal3fv(spn1); glVertex3fv(sp1);
            glNormal3fv(spn2); glVertex3fv(sp2);
            glNormal3fv(spn3); glVertex3fv(sp3);
        glEnd();
    }
    //Bottom
    j=nStack-1;
    for(i = 0;i < nSlice; i++){
        sp1 = sp[i][j];
        sp2 = sp[i][j+1];
        sp3 = sp[i+1][j]; 

        spn1 = spn[i][j];
        spn2 = spn[i][j+1];
        spn3 = spn[i+1][j]; 

        glBegin(GL_TRIANGLES);
            glNormal3fv(spn1); glVertex3fv(sp1);
            glNormal3fv(spn2); glVertex3fv(sp2);
            glNormal3fv(spn3); glVertex3fv(sp3);
        glEnd();
    }

    for(i = 0;i < nSlice;i++){
        for(j = 1;j < nStack-1; j++){
            sp1 = sp[i][j];
            sp2 = sp[i][j+1];
            sp3 = sp[i+1][j+1];
            sp4 = sp[i+1][j];

            spn1 = spn[i][j];
            spn2 = spn[i][j+1];
            spn3 = spn[i+1][j+1];
            spn4 = spn[i+1][j];

            glBegin(GL_QUADS);
                glNormal3fv(spn1); glVertex3fv(sp1);
                glNormal3fv(spn2); glVertex3fv(sp2);
                glNormal3fv(spn3); glVertex3fv(sp3);
                glNormal3fv(spn4); glVertex3fv(sp4);
            glEnd();
        }
    }
    
    glPopMatrix();

    glPolygonMode(GL_BACK, GL_FILL);
    glPolygonMode(GL_FRONT, GL_FILL);

    glDisable(GL_BLEND);
    glEnable(GL_DEPTH_TEST);
    glColor4f(1.0f,1.0f,1.0f,1.0f); 


}



//++++++++++++++++++++++++++++++++++ Draw cylinder ++++++++++++++++++++++++++++++++++++++++++++++++++
void drawCylinder(float x1, float y1, float z1, float x2,float y2, float z2, float radius1, float radius2, int subdivisions, int cap){

/*
  if(x1 == 0.0 && x2 == 0.0){
    x1 = 0.001;
  }
  if(y1 == 0.0 && y2 == 0.0){
    y1 = 0.001;
  }
  if(z1 == 0.0 && z2 == 0.0){
    z1 = 0.001;
  }
*/

  GLfloat vx = x2-x1;
  GLfloat vy = y2-y1;
  GLfloat vz = z2-z1;

  //handle the degenerate case with an approximation
/*
  if(vx < 0.001 && vx > 0.0){
    vx = 0.001;
  }
  if(vx > -0.001 && vx < 0.0){
    vx = -0.001;
  }
  if(vx == 0.0){
    vx = 0.001;
  }

  if(vy < 0.001 && vy > 0.0){
    vy = 0.001;
  }
  if(vy > -0.001 && vy < 0.0){
    vy = -0.001;
  }
  if(vy == 0.0){
    vy = 0.001;
  }
*/

  if(vz < 0.001 && vz > 0.0){
    vz = 0.001;
  }
  if(vz > -0.001 && vz < 0.0){
    vz = -0.001;
  }
  if(vz == 0.0){
    vz = 0.001;
  }
  
  
  GLfloat v = sqrt( vx*vx + vy*vy + vz*vz );
//  if(v<0.001)v=0.001;
  GLfloat ax = 57.2957795*acos( vz * 1000.0 / (v * 1000.0f) );//multiply with 1000.0f to avoid wrong result at small angles
  if ( vz < 0.0 ){
    ax = -ax;
  }
  GLfloat rx = -vy*vz * 1000.0f;//multiply with 1000.0f to avoid wrong result at small angles
  GLfloat ry = vx*vz * 1000.0f;//multiply with 1000.0f to avoid wrong result at small angles

  GLUquadricObj *quadric=gluNewQuadric();
  gluQuadricNormals(quadric, GLU_SMOOTH);

/*
  if(rx < 0.0001 && rx > 0.0){
    rx = 0.0001;
  }
  if(rx > -0.0001 && rx < 0.0){
    rx = -0.0001;
  }
  if(ry < 0.0001 && ry > 0.0){
    ry = 0.0001;
  }
  if(ry > -0.0001 && ry < 0.0){
    ry = -0.0001;
  }
*/
//ax = 89.5;//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

  glPushMatrix();
  glTranslatef( x1,y1,z1 );
  glRotatef(ax, rx, ry, 0.000001);
  
  //printf("vx = %lf, vy = %lf, vz = %lf, ax = %lf, rx = %lf, ry = %lf, v=%lf\n", vx, vy, vz, ax, rx, ry, v);
  
  //draw the cylinder
  gluCylinder(quadric, radius1, radius2, v, subdivisions, 1);
  gluQuadricOrientation(quadric,GLU_INSIDE);
  
  if(cap == 1){
    //draw the first cap
    gluDisk( quadric, 0.0, radius1, subdivisions, 1);
    glTranslatef( 0,0,v );
    //draw the second cap
    gluQuadricOrientation(quadric,GLU_OUTSIDE);
    gluDisk( quadric, 0.0, radius2, subdivisions, 1);
  }
  

  glPopMatrix();

  gluDeleteQuadric(quadric);
}

//++++++++++++++++++++++++++++++++++ Draw commutator ++++++++++++++++++++++++++++++++++++++++++++++++++
void drawCommutator(int n, int arg, GLfloat r, GLfloat l) {
  int i;
  GLfloat alpha;
  
  n=128;
  arg=0;
  r=2.0f;
  l=1.0f;

    glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
    glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
    glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
     

    // Cylinder Bottom
    glNormal3f(-1.0f,0.0f,0.0f);
    glBegin(GL_POLYGON);
//        glColor4f(1.0, 0.0, 0.0, 1.0);
        for(i = arg; i <= (360 + arg); i += (360 / n)) {
            float a = i * M_PI / 180; // degrees to radians
            glVertex3f(-l/2.0f, r * cos(a), r * sin(a));
        }
    glEnd();
 
    // Cylinder Top
    glNormal3f(1.0f,0.0f,0.0f);
    glBegin(GL_POLYGON);
//        glColor4f(0.0, 0.0, 1.0, 1.0);
        for(i = arg; i <= (360 + arg); i += (360 / n)) {
            float a = i * M_PI / 180; // degrees to radians
            glVertex3f(l/2.0f, r * cos(a), r * sin(a));
        }
    glEnd();
 

    GLfloat h = 1.0f;
    h=r * sin (2.0f * PI / n) / 2.0f + 0.005f;
    glRotatef(0.0f, 0.0f, 1.0f, 0.0f);  // rotate on the X axis
    for(alpha=0.0f; alpha < 360.0f + 360.0f / n; alpha += 360.0f / n){ 
      glBegin(GL_QUADS);		                // begin drawing a cube
      glNormal3f( 0.0f,1.0f, 0.0f);      
      glVertex3f(-l/2.0f, r, -h);	// Top Right Of The Texture and Quad
      glVertex3f( l/2.0f, r, -h);	// Top Left Of The Texture and Quad
      glVertex3f( l/2.0f, r,  h);	// Bottom Left Of The Texture and Quad
      glVertex3f(-l/2.0f, r,  h);	// Bottom Right Of The Texture and Quad
      glEnd();                                    // done with the polygon.
      glRotatef(alpha, 1.0f, 0.0f, 0.0f);  // rotate on the X axis
    }
    glRotatef(rotX, 0.0f, 1.0f, 0.0f);  // rotate on the X axis
//      glRotatef(rotX, 1.0f, 0.0f, 0.0f);  // rotate on the X axis
//      glRotatef(rotY, 0.0f, 1.0f, 0.0f);  // rotate on the Y axis
//      glRotatef(rotZ, 0.0f, 0.0f, 1.0f);  // rotate on the Z axis
 
 
}


void drawMagnet(GLfloat X, GLfloat Y, GLfloat Z, GLfloat L, GLfloat D, GLfloat angle){
  GLfloat alpha = 0.0f;


  glRotatef(angle, 1.0f, 0.0f, 0.0f);  /* rotate on the X axis */
//  glRotatef(rotY, 0.0f, 1.0f, 0.0f);  /* rotate on the Y axis */
//  glRotatef(rotZ, 0.0f, 0.0f, 1.0f);  /* rotate on the Z axis */


  //Draw magnetic poles

  //South pole
  glLightfv(GL_LIGHT1, GL_AMBIENT, lightGreen1);
  glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGreen1);
  glLightfv(GL_LIGHT1, GL_SPECULAR, lightGreen1);
  if(L < 0.0f){//swap poles
    drawCylinder(0.0f + X, 0.0f + Y, 0.0f + Z, 0.0f + X, 0.0f + Y, -L + Z, D, D, 32, 1);
  }
  else{
    drawCylinder(0.0f + X, 0.0f + Y, -L + Z, 0.0f + X, 0.0f + Y, 0.0f + Z, D, D, 32, 1);
  }
  //Draw S
  GLfloat Sx1, Sx2, Sy1, Sy2;

  if((L > 0.0f && enableOrtho) || (L < 0.0f && !enableOrtho)){//swap poles
    alpha = 0.0f;
    Sx2 = cos(alpha -0.050f + PI * 0.15f) * D * 0.3f;
    Sy2 = sin(alpha -0.050f + PI * 0.15f) * D * 0.3f + D * 0.35f;
    for(alpha = 0.0f; alpha < PI + PI * 0.375f; alpha+=0.1){
      Sx1 = cos(alpha + PI * 0.15f) * D * 0.3f;
      Sy1 = sin(alpha + PI * 0.15f) * D * 0.3f + D * 0.35f;
      drawCylinder(Sx1 + X, Sy1 + Y, -L + Z, Sx2 + X, Sy2 + Y, -L + Z, 0.1f, 0.1f, 32, 0);
      Sx2 = cos(alpha -0.050f + PI * 0.15f) * D * 0.3f;
      Sy2 = sin(alpha -0.050f + PI * 0.15f) * D * 0.3f + D * 0.35f;
    }
    alpha=0.0f;
    Sx2 = cos(alpha - 0.035f + PI * 1.150f) * D * 0.4f;
    Sy2 = sin(alpha - 0.035f + PI * 1.150f) * D * 0.4f - D * 0.35f;
    for(alpha = 0.0f; alpha < PI + PI * 0.375f; alpha+=0.1){
      Sx1 = cos(alpha + PI * 1.150f) * D * 0.4f;
      Sy1 = sin(alpha + PI * 1.150f) * D * 0.4f - D * 0.35f;
      drawCylinder(Sx1 + X, Sy1 + Y, -L + Z, Sx2 + X, Sy2 + Y, -L + Z, 0.1f, 0.1f, 32, 0);
      Sx2 = cos(alpha - 0.035f + PI * 1.150f) * D * 0.4f;
      Sy2 = sin(alpha - 0.035f + PI * 1.150f) * D * 0.4f - D * 0.35f;
    }
  }
  else{
    alpha = 0.0f;
    Sx2 = cos(alpha -0.050f + PI * 1.5f) * D * 0.3f;
    Sy2 = sin(alpha -0.050f + PI * 1.5f) * D * 0.3f + D * 0.35f;
    for(alpha = 0.0f; alpha < PI + PI * 0.375f; alpha+=0.1){
      Sx1 = cos(alpha + PI * 1.5f) * D * 0.3f;
      Sy1 = sin(alpha + PI * 1.5f) * D * 0.3f + D * 0.35f;
      drawCylinder(Sx1 + X, Sy1 + Y, -L + Z, Sx2 + X, Sy2 + Y, -L + Z, 0.1f, 0.1f, 32, 0);
      Sx2 = cos(alpha -0.050f + PI * 1.5f) * D * 0.3f;
      Sy2 = sin(alpha -0.050f + PI * 1.5f) * D * 0.3f + D * 0.35f;
    }
    alpha=0.0f;
    Sx2 = cos(alpha - 0.035f + PI * 0.5f) * D * 0.4f;
    Sy2 = sin(alpha - 0.035f + PI * 0.5f) * D * 0.4f - D * 0.35f;
    for(alpha = 0.0f; alpha < PI + PI * 0.375f; alpha+=0.1){
      Sx1 = cos(alpha + PI * 0.5f) * D * 0.4f;
      Sy1 = sin(alpha + PI * 0.5f) * D * 0.4f - D * 0.35f;
      drawCylinder(Sx1 + X, Sy1 + Y, -L + Z, Sx2 + X, Sy2 + Y, -L + Z, 0.1f, 0.1f, 32, 0);
      Sx2 = cos(alpha - 0.035f + PI * 0.5f) * D * 0.4f;
      Sy2 = sin(alpha - 0.035f + PI * 0.5f) * D * 0.4f - D * 0.35f;
    }
  }

  //North pole
  glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
  glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
  glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);
  if(L < 0.0f){//swap poles
    drawCylinder(0.0f + X, 0.0f + Y, L + Z, 0.0f + X, 0.0f + Y,  0.0f + Z, D, D, 32, 1);
  }
  else{
    drawCylinder(0.0f + X, 0.0f + Y, 0.0f + Z, 0.0f + X, 0.0f + Y,  L + Z, D, D, 32, 1);
  }
  
  //Draw N
  drawCylinder(D * 0.5f + X, -D * 0.8f + Y, L + Z, D * 0.5f + X, D * 0.8f + Y, L + Z, 0.1f, 0.1f, 32, 0);
  if((L > 0.0f && enableOrtho) || (L < 0.0f && !enableOrtho)){//swap poles
    drawCylinder(-D * 0.5f + X, -D * 0.8f + Y, L + Z, D * 0.5f + X, D * 0.8f + Y, L + Z, 0.1f, 0.1f, 32, 0);
  }
  else{
    drawCylinder(D * 0.5f + X, -D * 0.8f + Y, L + Z, -D * 0.5f + X, D * 0.8f + Y, L + Z, 0.1f, 0.1f, 32, 0);
  }
  drawCylinder(-D * 0.5f + X, -D * 0.8f + Y, L + Z, -D * 0.5f + X, D * 0.8f + Y, L + Z, 0.1f, 0.1f, 32, 0);


  glRotatef(-angle, 1.0f, 0.0f, 0.0f);  /* rotate on the X axis */
  
}

//+++++++++++++++++++++++++++++++++ Drawing code +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
/* Here goes our drawing code */
int drawGLScene(GLvoid){
    char textLine[1000];
    int i;
    GLfloat alpha;

    if(animationPause == 0){
      animationFrames++;
      translateX += translateXdiff;
      translateY += translateYdiff;
      translateZ += translateZdiff;
      rotX += rotXdiff;
      rotY += rotYdiff;
      rotZ += rotZdiff;
    }
    
    usleep(slowDownMS);
    
    
    glColor4f(1.0f,1.0f,1.0f,1.0f);         // Full Brightness, 50% Alpha ( NEW )
    glBlendFunc(GL_SRC_ALPHA,GL_ONE);       // Blending Function For Translucency Based On Source Alpha 
        
    
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    
    glLightfv(GL_LIGHT1, GL_POSITION, lightPosition1);
    
    glLoadIdentity();
    glTranslatef(translateX, translateY, translateZ);
    glRotatef(rotX, 1.0f, 0.0f, 0.0f);  /* rotate on the X axis */
    glRotatef(rotY, 0.0f, 1.0f, 0.0f);  /* rotate on the Y axis */
    glRotatef(rotZ, 0.0f, 0.0f, 1.0f);  /* rotate on the Z axis */
    //glColor3f(1.0f, 1.0f, 0.0f);
    


    //glEnable(GL_BLEND);
    //glDisable(GL_DEPTH_TEST);
    glEnable(GL_LIGHTING);
    glLineWidth(4.5);
    glPolygonMode(GL_BACK, GL_FILL);
    glPolygonMode(GL_FRONT, GL_FILL);
    glDisable(GL_BLEND);
    glEnable(GL_DEPTH_TEST);
    glColor4f(1.0f,1.0f,1.0f,1.0f); 
    
    glPolygonMode(GL_BACK, GL_FILL);
    glPolygonMode(GL_FRONT, GL_FILL);


    for(i = 0; i < MAGNETMAX; i++){//Fixed magnets
      if(enableMagnet[i] == 2){
        if(enableSwapMagnet[i]){
          drawMagnet(MagnetX[i], MagnetY[i], MagnetZ[i], -MagnetL[i], MagnetD[i], MagnetRot[i]);
        }
        else{
          drawMagnet(MagnetX[i], MagnetY[i], MagnetZ[i], MagnetL[i], MagnetD[i], MagnetRot[i]);
        }
      }//if(enableMagnet[0]){
    }

    if(enableCommutator){
      //rotX=0.0f;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      //rotY = 90.0f;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//enableSwapMotor = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

//enableMotorRot = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//MotorRotSpeed = 0.324324324f;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      if(enablePositronsAll) enablePositrons = True;

      if(!enablePath3){
        if(enablePositronsAll) enablePositronMovement = True;
        if(enableMagnetsAll) enableMagnet[0] = True;
        if(enableMagnetsAll) enableMagnet[1] = True;
        if(enablePath2){
          if(enablePositronsAll) enablePositronMovement2 = True;
          if(enableMagnetsAll) enableMagnet[4] = True;
          if(enableMagnetsAll) enableMagnet[5] = True;
        }
        if(enablePositronsAll) enablePositrons = True;
      }
      else{
        if(enablePositronsAll) enablePositronMovement = False;
        if(enablePositronsAll) enablePositronMovement2 = False;
        if(enablePositronsAll) enablePositronMovement3 = False;
        if(enableMagnetsAll) enableMagnet[0] = False;
        if(enableMagnetsAll) enableMagnet[1] = False;
        if(enableMagnetsAll) enableMagnet[4] = False;
      }

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
      GLfloat commutatorYo = 0.6f;
      GLfloat commutatorYu = 0.6f;
      GLfloat temp = 0.6f;
      GLfloat CommutatorAlpha = MotorRotX;
      GLfloat alphaStart1 = 30.15f, alphaEnd1 = 150.15f;
      GLfloat alphaStart2 = 46.0f, alphaEnd2 = 134.0f;
      //printf("lastPositronActive2=%d, pathNumber2=%d\n", lastPositronActive2, pathNumber2);

      if(!enablePath2){
        alphaStart1 = 30.15f;
        alphaEnd1 = 150.15f;
      }
      else{
        alphaStart1 = 44.0f;
        alphaEnd1 = 136.0f;
      }
      
      if(!enablePath3){
        while(CommutatorAlpha > 180.0f){
          CommutatorAlpha -= 180.0f;
        }
        while(CommutatorAlpha < 0.0f){
          CommutatorAlpha += 180.0f;
        }
      }
      else{
        while(CommutatorAlpha > 360.0f){
          CommutatorAlpha -= 360.0f;
        }
        while(CommutatorAlpha < 0.0f){
          CommutatorAlpha += 360.0f;
        }
      }
      //printf("CommutatorAlpha=%lf\n", CommutatorAlpha);

      commutatorYo = 0.40f * sin(CommutatorAlpha * PI / 180.0f) + 0.2f;
      if(enablePath2 && !enablePath3){
        temp = 0.40f * sin((CommutatorAlpha + 90.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
        temp = 0.40f * sin((CommutatorAlpha - 90.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
      }
      if(enablePath3){
        commutatorYo = 0.60f * sin(CommutatorAlpha * PI / 180.0f) + 0.2f;
        temp = 0.60f * sin((CommutatorAlpha + 40.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 120.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 160.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 240.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 280.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYo){
          commutatorYo = temp;
        }

        commutatorYu = 0.60f * sin((CommutatorAlpha + 180.0f) * PI / 180.0f) + 0.2f;
        temp = 0.60f * sin((CommutatorAlpha + 40.0f + 180.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYu){
          commutatorYu = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 120.0f + 180.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYu){
          commutatorYu = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 160.0f + 180.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYu){
          commutatorYu = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 240.0f + 180.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYu){
          commutatorYu = temp;
        }
        temp = 0.60f * sin((CommutatorAlpha + 280.0f + 180.0f) * PI / 180.0f) + 0.2f;
        if(temp > commutatorYu){
          commutatorYu = temp;
        }
        //printf("commutatorYo=%lf, commutatorYu=%lf\n", commutatorYo, commutatorYu);
        //printf("CommutatorAlpha=%lf\n", CommutatorAlpha);
      }

      if(commutatorYo < 0.4f){
        commutatorYo = 0.4f;
      }
      if(commutatorYu < 0.4f){
        commutatorYu = 0.4f;
      }
      
      if(!enablePath3){
        if(!(CommutatorAlpha > alphaStart1 && CommutatorAlpha < alphaEnd1)){//Contact zone 1
          
          if(enablePositronsAll) enablePositronMovement = False;
          if(enableMagnetsAll) enableMagnet[0] = False;
          if(enableMagnetsAll) enableMagnet[1] = False;

          if(isCommutatorContact){
            printf("CommutatorAlpha=%lf\n", CommutatorAlpha);
            printf("contactFrames=%d\n", contactFrames);
            contactFrames = 0;
            if(enableSwapPolarity){
              enableSwapPolarity = False;
              if(paintPath>0){
                if(enableMagnetsAll) enableSwapMagnet[0] = False;
                if(enableMagnetsAll) enableSwapMagnet[1] = False;
              }
              else{
                if(enableMagnetsAll) enableSwapMagnet[0] = True;
                if(enableMagnetsAll) enableSwapMagnet[1] = True;
              }
            }
            else{
              enableSwapPolarity = True;
              if(paintPath > 0){
                if(enableMagnetsAll) enableSwapMagnet[0] = True;
                if(enableMagnetsAll) enableSwapMagnet[1] = True;
              }
              else{
                if(enableMagnetsAll) enableSwapMagnet[0] = False;
                if(enableMagnetsAll) enableSwapMagnet[1] = False;
              }
            }
            isCommutatorContact = False;
          }


        }
        else{
          if(!isCommutatorContact){
            printf("CommutatorAlpha=%lf\n", CommutatorAlpha);
          }
          contactFrames++;
          isCommutatorContact = True;
        }//Contact zone 1
        
        if(CommutatorAlpha > alphaStart2 && CommutatorAlpha < alphaEnd2){//Contact zone 2
          
          if(enablePositronsAll) enablePositronMovement2 = False;
          if(enableMagnetsAll) enableMagnet[4] = False;
          if(enableMagnetsAll) enableMagnet[5] = False;

          if(isCommutatorContact2){
            printf("CommutatorAlpha=%lf\n", CommutatorAlpha);
            printf("contactFrames=%d\n", contactFrames);
            if(enableSwapPolarity2){
              enableSwapPolarity2 = False;
              if(paintPath > 0){
                if(enableMagnetsAll) enableSwapMagnet[4] = True;
                if(enableMagnetsAll) enableSwapMagnet[5] = True;
              }
              else{
                if(enableMagnetsAll) enableSwapMagnet[4] = False;
                if(enableMagnetsAll) enableSwapMagnet[5] = False;
              }
            }
            else{
              enableSwapPolarity2 = True;
              if(paintPath > 0){
                if(enableMagnetsAll) enableSwapMagnet[4] = False;
                if(enableMagnetsAll) enableSwapMagnet[5] = False;
              }
              else{
                if(enableMagnetsAll) enableSwapMagnet[4] = True;
                if(enableMagnetsAll) enableSwapMagnet[5] = True;
              }
            }
            isCommutatorContact2 = False;
          }
        }
        else{
//          if(!isCommutatorContact2){
//            printf("CommutatorAlpha=%lf\n", CommutatorAlpha);
//          }
          isCommutatorContact2 = True;
        }//Contact zone 2
        commutatorYu = commutatorYo;
      }//if(!enablePath3){
      else{
        if(CommutatorAlpha > 187.0f && CommutatorAlpha < 252.0f){//Contact zone 1a
          if(enablePositronsAll) enablePositronMovement = True;
          if(enablePositronsAll) enableSwapPolarity = True;
          if(enableMagnetsAll) enableMagnet[0] = True;
          if(enableMagnetsAll) enableSwapMagnet[0] = False;
        }
        if(CommutatorAlpha > 6.0f && CommutatorAlpha < 72.0f){//Contact zone 1b
          if(enablePositronsAll) enablePositronMovement = True;
          if(enablePositronsAll) enableSwapPolarity = False;
          if(enableMagnetsAll) enableMagnet[0] = True;
          if(enableMagnetsAll) enableSwapMagnet[0] = True;
        }
        if(CommutatorAlpha > 67.0f && CommutatorAlpha < 132.0f){//Contact zone 2a
          if(enablePositronsAll) enablePositronMovement2 = True;
          if(enablePositronsAll) enableSwapPolarity2 = True;
          if(enableMagnetsAll) enableMagnet[1] = True;
          if(enableMagnetsAll) enableSwapMagnet[1] = False;
        }
        if(CommutatorAlpha > 246.0f && CommutatorAlpha < 312.0f){//Contact zone 2b
          if(enablePositronsAll) enablePositronMovement2 = True;
          if(enablePositronsAll) enableSwapPolarity2 = False;
          if(enableMagnetsAll) enableMagnet[1] = True;
          if(enableMagnetsAll) enableSwapMagnet[1] = True;
        }
        if(CommutatorAlpha > 307.0f || CommutatorAlpha < 12.0f){//Contact zone 3a
          if(enablePositronsAll) enablePositronMovement3 = True;
          if(enablePositronsAll) enableSwapPolarity3 = True;
          if(enableMagnetsAll) enableMagnet[4] = True;
          if(enableMagnetsAll) enableSwapMagnet[4] = False;
        }
        if(CommutatorAlpha > 126.0f && CommutatorAlpha < 192.0f){//Contact zone 3b
          if(enablePositronsAll) enablePositronMovement3 = True;
          if(enablePositronsAll) enableSwapPolarity3 = False;
          if(enableMagnetsAll) enableMagnet[4] = True;
          if(enableMagnetsAll) enableSwapMagnet[4] = True;
        }
      }
      
      
      commutatorYo = 4.7f*(commutatorYo-0.4f)/4.0f + 0.4f;
      commutatorYo += 0.2f;
      commutatorYu = 4.7f*(commutatorYu-0.4f)/4.0f + 0.4f;
      commutatorYu += 0.2f;
      drawCylinder(Bat1X1, 0.6f, -4.0f, Bat1X1, commutatorYo, 0.7f, 0.2f, 0.2f, 16, 1);
      drawSphere(Bat1X1, 0.6f, -4.0f, 0.2f, 20, 20, 0);
      drawCylinder(Bat1X1, 0.6f, -4.0f, Bat1X1, -2.5f, -4.0f, 0.2f, 0.2f, 16, 1);

      drawCylinder(Bat1X1, -0.6f, 4.0f, Bat1X1, -commutatorYu+0.0001, -0.7f, 0.2f, 0.2f, 16, 1);
      drawSphere(Bat1X1, -0.6f, 4.0f, 0.2f, 20, 20, 0);
      drawCylinder(Bat1X1, -0.6f, 4.0f, Bat1X1, -2.5f, 4.0f, 0.2f, 0.2f, 16, 1);

      //Draw positrons at commutator lines
      if(paintPath > 0){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
      }
      else{
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);
      }
      


      if(enablePath2){
        if(enableSwapMotor){
          for(i=positronPlusPos; i>0; i-=25){
            if(i < 95){
              drawSphere(Bat1X1, -2.5f + i * (1.9f/95.0f), 4.0f, 0.3f, 20, 20, 0);
            }
            if(i == 95){
              drawSphere(Bat1X1, 0.6f, -4.0f, 0.3f, 20, 20, 0);
            }
            if(i > 95){
              temp = commutatorYo;
              temp = temp - 0.6f;
              temp = temp * 4.0f / 4.7f;
              temp = temp * (95-(190.0f-i)) / 95.0f;
              temp += 0.6f;
              drawSphere(Bat1X1, -temp, (190-i) * 4.0f / 95.0f, 0.3f, 20, 20, 0);
//              drawSphere(Bat1X1, -temp, (95-i) * 4.0f / 95.0f, 0.3f, 20, 20, 0);
//              drawSphere(Bat1X1, -temp, (4.0f - i * 4.0f / 95.0f) + 4.0f, 0.3f, 20, 20, 0);
            }
            if(positronPlusPos < 165 && (enablePositronMovement || enablePath2)){
              positronPlusPos++;
            }
          }
        }
        else{
          for(i=positronPlusPos; i>0; i-=25){
            if(i < 95){
              drawSphere(Bat1X1, -2.5f + i * (3.1f/95.0f), -4.0f, 0.3f, 20, 20, 0);
            }
            if(i == 95){
              drawSphere(Bat1X1, 0.6f, -4.0f, 0.3f, 20, 20, 0);
            }
            if(i > 95){
              temp = commutatorYo;
              temp = temp - 0.6f;
              temp = temp * 4.0f / 4.7f;
              temp = temp * (95-(190-i)) / 95.0f;
              temp += 0.6f;
              drawSphere(Bat1X1, temp, -4.0 + (i - 95) * 4.0f / 95.0f, 0.3f, 20, 20, 0);
            }
            if(positronPlusPos < 165 && (enablePositronMovement || enablePath2)){
              positronPlusPos++;
            }
          }
        }
      }
      else{
        if(positronPlusPos < 95){
          drawSphere(Bat1X1, -2.5f + positronPlusPos * (3.1f/95.0f), -4.0f, 0.3f, 20, 20, 0);
        }
        if(positronPlusPos == 95){
          drawSphere(Bat1X1, 0.6f, -4.0f, 0.3f, 20, 20, 0);
        }
        if(positronPlusPos > 95){
          temp = commutatorYo;
          temp = temp - 0.6f;
          temp = temp * 4.0f / 4.7f;
          temp = temp * (positronPlusPos - 95) / 95.0f;
          temp += 0.6f;
          drawSphere(Bat1X1, temp, -4.0 + (positronPlusPos - 95) * 4.0f / 95.0f, 0.3f, 20, 20, 0);
        }
        if(positronPlusPos < 195 && (enablePositronMovement || enablePath2)){
          positronPlusPos+=positronStep;
        }
      }
      
      if(enableSwapMotor){
        if(positronMinusPos < 95){
          temp = commutatorYo;
          temp = temp - 0.6f;
          temp = temp * 4.0f / 4.7f;
          temp = -temp * (95-positronMinusPos) / 95.0f;
          temp -= 0.6f;
          drawSphere(Bat1X2, -temp, (95-positronMinusPos) * 4.0f / 95.0f - 4.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos == 95){
          drawSphere(Bat1X2, 0.6f, -4.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos > 95 && positronMinusPos < 185){
          drawSphere(Bat1X2, 0.6f - (positronMinusPos - 95) * (3.1f/95.0f), -4.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos < 185 && (enablePositronMovement || enablePath2)){
          if(enablePath2){
            positronMinusPos+=5;
          }
          else{
            positronMinusPos+=positronStep;
          }
        }
      }
      else{
        if(positronMinusPos < 95){
          temp = commutatorYu;
          temp = temp - 0.6f;
          temp = temp * 4.0f / 4.7f;
          temp = temp * (95-positronMinusPos) / 95.0f;
          temp += 0.6f;
          drawSphere(Bat1X1, -temp, positronMinusPos * 4.0f / 95.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos == 95){
          drawSphere(Bat1X1, -0.6f, 4.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos > 95 && positronMinusPos < 185){
          drawSphere(Bat1X1, -0.6f - (positronMinusPos - 95) * (1.9f/95.0f), 4.0f, 0.3f, 20, 20, 0);
        }
        if(positronMinusPos < 185 && (enablePositronMovement || enablePath2)){
          if(enablePath2){
            positronMinusPos+=5;
          }
          else{
            positronMinusPos+=positronStep;
            //printf("positronMinusPos=%d, enablePositronMovement2=%d\n", positronMinusPos, enablePositronMovement2);
          }
        }
      }
        
//enablePositronMovement2 = True; // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      
    }//if(enableCommutator){


    if(enableBattery2){


      //Draw minus / plus
      if(enableSwapMotor || paintPath > 0){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);
        drawCylinder(Bat2X2, Bat2Y2-0.4f, Bat2Z2, Bat2X2, Bat2Y2+0.4f, Bat2Z2, 0.1f, 0.1f, 16, 0);
      }
      else{
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGrey1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGrey1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGrey1);
      }
      drawCylinder(Bat2X2, Bat2Y2, Bat2Z2-0.4f, Bat2X2, Bat2Y2, Bat2Z2+0.4f, 0.1f, 0.1f, 16, 0);

      GLfloat y1, z1, y2, z2;
      y2 = 0.4f * cos(-0.14f) + Bat2Y2;
      z2 = 0.4f * sin(-0.14f) + Bat2Z2;
      for(alpha=0.0f; alpha < 2.0f * PI; alpha+=0.05f){
        y1 = 0.4f * cos(alpha+0.04f) + Bat2Y2;
        z1 = 0.4f * sin(alpha+0.04f) + Bat2Z2;
        drawCylinder(Bat2X2, y1, z1, Bat2X2, y2, z2, 0.1f, 0.1f, 16, 0);
        y2 = 0.4f * cos(alpha) + Bat2Y2;
        z2 = 0.4f * sin(alpha) + Bat2Z2;
      }

      if(enableSwapMotor || paintPath > 0){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGrey1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGrey1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGrey1);
      }
      else{
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);
        drawCylinder(Bat2X1, Bat2Y1-0.4f, Bat2Z1, Bat2X1, Bat2Y1+0.4f, Bat2Z1, 0.1f, 0.1f, 16, 0);
      }
        
      drawCylinder(Bat2X1, Bat2Y1, Bat2Z1-0.4f, Bat2X1, Bat2Y1, Bat2Z1+0.4f, 0.1f, 0.1f, 16, 0);

      y2 = 0.4f * cos(-0.14f) + Bat2Y1;
      z2 = 0.4f * sin(-0.14f) + Bat2Z1;
      for(alpha=0.0f; alpha < 2.0f * PI; alpha+=0.05f){
        y1 = 0.4f * cos(alpha+0.04f) + Bat2Y1;
        z1 = 0.4f * sin(alpha+0.04f) + Bat2Z1;
        drawCylinder(Bat2X1, y1, z1, Bat2X1, y2, z2, 0.1f, 0.1f, 16, 0);
        y2 = 0.4f * cos(alpha) + Bat2Y1;
        z2 = 0.4f * sin(alpha) + Bat2Z1;
      }
    }//if(enableBattery2){

    if(enableMotorRot){
      MotorRotX+=MotorRotSpeed;
    }
    glRotatef(MotorRotX, 1.0f, 0.0f, 0.0f);//Rotate motor



    glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
    glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
    glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

    if(enableBlueWire){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
    }
    if(enableGoldenWire){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
    }

    //Corner points of "cable"
    for(i=0; i<maxPathCorners; i++){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);
      if(enableBlueWire){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
      }
      if(enableGoldenWire){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
      }
      if(animation == 1 || animation == 2){
        if(animation == 1){
          if(paintPath>40 && i == 0 ||
             paintPath>220 && i == 1 ||
             paintPath>260 && i == 2 ||
             paintPath>12869 && i == 3 ||
             paintPath>13044 && i == 4){
            glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
            glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
            glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
          }
        }
        if(animation == 2){
          if(paintPath>40 && i == 0 ||
             paintPath>220 && i == 1 ||
             paintPath>12828 && i == 2 ||
             paintPath>12869 && i == 3 ||
             paintPath>13044 && i == 4){
            glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
            glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
            glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
          }
        }
      }
      else{
        if(paintPath>108 && i == 0 ||
           paintPath>392 && i == 1 ||
           paintPath>432 && i == 2 ||
           paintPath>6558 && i == 3 ||
           paintPath>6763 && i == 4 ||
           paintPath>13202 && i == 5 ||
           paintPath>13243 && i == 6 ||
           paintPath>13532 && i == 7){
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
        }
      }
      
      drawSphere(pathCorners[i][0], pathCorners[i][1], pathCorners[i][2], 0.2f, 20, 20, 0);
    }
    //path as 3D cylinders
    for(i=0; i<pathNumber-2; i++){
      if(paintPath > 0){
        if(i<paintPath){
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
        }
        else{
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);
          if(enableBlueWire){
            glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
            glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
            glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
          }
          if(enableGoldenWire){
            glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
            glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
            glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
          }
        }
      }
      drawCylinder(path[i][0], path[i][1], path[i][2], path[i][3], path[i][4], path[i][5], 0.2f, 0.2f, 16, 0);
    }

    if(enablePath2){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);

      //Corner points of "cable"
      for(i=0; i<maxPathCorners; i++){
        if(paintPath2>108 && i == 0 ||
           paintPath2>392 && i == 1 ||
           paintPath2>432 && i == 2 ||
           paintPath2>6637 && i == 3 ||
           paintPath2>6840 && i == 4 ||
           paintPath2>13201 && i == 5 ||
           paintPath2>13242 && i == 6 ||
           paintPath2>13529 && i == 7){
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
        }
        else{
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
        }
        drawSphere(pathCorners2[i][0], pathCorners2[i][1], pathCorners2[i][2], 0.2f, 20, 20, 0);
      }
      //path as 3D cylinders
      for(i=0; i<pathNumber2-2; i++){
        if(i<paintPath2){
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
        }
        else{
          glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
          glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
          glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
        }
        drawCylinder(path2[i][0], path2[i][1], path2[i][2], path2[i][3], path2[i][4], path2[i][5], 0.2f, 0.2f, 16, 0);
      }
    }

    if(enablePath3){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightMagenta2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightMagenta2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightMagenta2);

      //Corner points of "cable"
      for(i=0; i<maxPathCorners; i++){
        drawSphere(pathCorners3[i][0], pathCorners3[i][1], pathCorners3[i][2], 0.2f, 20, 20, 0);
      }
      //path as 3D cylinders
      for(i=0; i<pathNumber3-2; i++){
        drawCylinder(path3[i][0], path3[i][1], path3[i][2], path3[i][3], path3[i][4], path3[i][5], 0.2f, 0.2f, 16, 0);
      }
    }


    if(enableAxis){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGrey1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGrey1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGrey1);
      drawCylinder(-3.0f, 0.0f, 0.0f, 7.0f, 0.0f, 0.0f, 0.2f, 0.2f, 16, 1);
    }

    if(enableCommutator){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
      drawCylinder(Bat1X1 + 0.5f, Bat1Y1, Bat1Z1, Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 0.225f, 0.225f, 16, 1);
      drawCylinder(Bat1X2 + 0.5f, Bat1Y2, Bat1Z2, Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 0.225f, 0.225f, 16, 1);
      if(enablePath3){
        glRotatef(120.0f, 1.0f, 0.0f, 0.0f);//Rotate motor
        drawCylinder(Bat1X1 + 0.5f, Bat1Y1, Bat1Z1, Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 0.225f, 0.225f, 16, 1);
        drawCylinder(Bat1X2 + 0.5f, Bat1Y2, Bat1Z2, Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 0.225f, 0.225f, 16, 1);
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
        drawCylinder(Bat1X1 + 0.51f, Bat1Y1, Bat1Z1, Bat1X1, Bat1Y1, Bat1Z1, 0.1f, 0.1f, 16, 1);
        drawCylinder(Bat1X2 + 0.51f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.15f, 0.15f, 16, 1);
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
        drawCylinder(Bat1X2 + 0.515f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.1f, 0.1f, 16, 1);
        glRotatef(120.0f, 1.0f, 0.0f, 0.0f);//Rotate motor
        drawCylinder(Bat1X1 + 0.5f, Bat1Y1, Bat1Z1, Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 0.225f, 0.225f, 16, 1);
        drawCylinder(Bat1X2 + 0.5f, Bat1Y2, Bat1Z2, Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 0.225f, 0.225f, 16, 1);
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightMagenta1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightMagenta1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightMagenta1);
        drawCylinder(Bat1X1 + 0.51f, Bat1Y1, Bat1Z1, Bat1X1, Bat1Y1, Bat1Z1, 0.1f, 0.1f, 16, 1);
        drawCylinder(Bat1X2 + 0.51f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.15f, 0.15f, 16, 1);
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
        drawCylinder(Bat1X2 + 0.515f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.1f, 0.1f, 16, 1);
        glRotatef(-240.0f, 1.0f, 0.0f, 0.0f);//Rotate motor
      }
      if(enablePath2 && !enablePath3){
        drawCylinder(Bat1X1 + 0.5f, Bat1Z1, Bat1Y1, Bat1X1 - 0.5f, Bat1Z1, Bat1Y1, 0.225f, 0.225f, 16, 1);
        drawCylinder(Bat1X2 + 0.5f, Bat1Z2, Bat1Y2, Bat1X2 - 0.5f, Bat1Z2, Bat1Y2, 0.225f, 0.225f, 16, 1);

        glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue3);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue3);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue3);
        drawCylinder(Bat1X1 + 0.51f, Bat1Z1, Bat1Y1, Bat1X1, Bat1Z1, Bat1Y1, 0.1f, 0.1f, 16, 1);
        drawCylinder(Bat1X2 + 0.51f, Bat1Z2, Bat1Y2, Bat1X2, Bat1Z2, Bat1Y2, 0.15f, 0.15f, 16, 1);

        glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
        drawCylinder(Bat1X2 + 0.515f, Bat1Z2, Bat1Y2, Bat1X2, Bat1Z2, Bat1Y2, 0.1f, 0.1f, 16, 1);
      }
      
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);
      drawCylinder(Bat1X1 + 0.51f, Bat1Y1, Bat1Z1, Bat1X1, Bat1Y1, Bat1Z1, 0.1f, 0.1f, 16, 1);
      drawCylinder(Bat1X2 + 0.51f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.15f, 0.15f, 16, 1);

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
      drawCylinder(Bat1X2 + 0.515f, Bat1Y2, Bat1Z2, Bat1X2, Bat1Y2, Bat1Z2, 0.1f, 0.1f, 16, 1);
    }

    if(enableBattery1){

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGrey1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGrey1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGrey1);

      //Draw minus
      drawCylinder(Bat1X2, Bat1Y2, Bat1Z2-0.4f, Bat1X2, Bat1Y2, Bat1Z2+0.4f, 0.1f, 0.1f, 16, 0);

      GLfloat y1, z1, y2, z2;
      y2 = 0.4f * cos(-0.14f) + Bat1Y2;
      z2 = 0.4f * sin(-0.14f) + Bat1Z2;
      for(alpha=0.0f; alpha < 2.0f * PI; alpha+=0.05f){
        y1 = 0.4f * cos(alpha+0.04f) + Bat1Y2;
        z1 = 0.4f * sin(alpha+0.04f) + Bat1Z2;
        drawCylinder(Bat1X2, y1, z1, Bat1X2, y2, z2, 0.1f, 0.1f, 16, 0);
        y2 = 0.4f * cos(alpha) + Bat1Y2;
        z2 = 0.4f * sin(alpha) + Bat1Z2;
      }

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);

      //Draw plus
      drawCylinder(Bat1X1, Bat1Y1-0.4f, Bat1Z1, Bat1X1, Bat1Y1+0.4f, Bat1Z1, 0.1f, 0.1f, 16, 0);
      drawCylinder(Bat1X1, Bat1Y1, Bat1Z1-0.4f, Bat1X1, Bat1Y1, Bat1Z1+0.4f, 0.1f, 0.1f, 16, 0);

      y2 = 0.4f * cos(-0.14f) + Bat1Y1;
      z2 = 0.4f * sin(-0.14f) + Bat1Z1;
      for(alpha=0.0f; alpha < 2.0f * PI; alpha+=0.05f){
        y1 = 0.4f * cos(alpha+0.04f) + Bat1Y1;
        z1 = 0.4f * sin(alpha+0.04f) + Bat1Z1;
        drawCylinder(Bat1X1, y1, z1, Bat1X1, y2, z2, 0.1f, 0.1f, 16, 0);
        y2 = 0.4f * cos(alpha) + Bat1Y1;
        z2 = 0.4f * sin(alpha) + Bat1Z1;
      }
    }//if(enableBattery1){
    
    if(enableWhitePositrons){
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);
    }
    else{
      if(enableBluePositrons){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue1);
      }
      else{
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);
      }
    }

    if(enablePositrons){
      for(i=0; i<lastPositronActive; i++){
        drawSphere(path[positron[i]][0], path[positron[i]][1], path[positron[i]][2], 0.3f, 20, 20, 0);
        if(enablePositronMovement){
          if(enableSwapPolarity){
            positron[i]-=positronStep;//Move positrons reverse
            if(positron[i] < 0){
              printf("positron[%d] = %d!\n", i, positron[i]);
              positron[i] = 0;
            }
          }
          else{
            positron[i]+=positronStep;//Move positrons
          }
        }
      }

      if(enablePath2){
        for(i=0; i<lastPositronActive2; i++){
          drawSphere(path2[positron2[i]][0], path2[positron2[i]][1], path2[positron2[i]][2], 0.3f, 20, 20, 0);
          if(enablePositronMovement2){
            if(enableSwapPolarity2){
              positron2[i]-=positronStep;//Move positrons reverse
              if(positron2[i] < 0){
                printf("positron2[%d] = %d!\n", i, positron2[i]);
                positron2[i] = 0;
              }
            }
            else{
              positron2[i]+=positronStep;//Move positrons
            }
          }
        }
      }

      if(enablePath3){
        for(i=0; i<lastPositronActive3; i++){
          drawSphere(path3[positron3[i]][0], path3[positron3[i]][1], path3[positron3[i]][2], 0.3f, 20, 20, 0);
          if(enablePositronMovement3){
            if(enableSwapPolarity3){
              positron3[i]-=positronStep;//Move positrons reverse
              if(positron3[i] < 0){
                printf("positron3[%d] = %d!\n", i, positron3[i]);
                positron3[i] = 0;
              }
            }
            else{
              positron3[i]+=positronStep;//Move positrons
            }
          }
        }
      }

      if(enablePositronMovement){
        if(enableSwapPolarity){//Reverse movoment
          if(positron[lastPositronActive-1] == 0){
            lastPositronActive--;
            positronMinusPos = 0;
          }

          if(pathNumber - positron[0] > 185){
            lastPositronActive++;
            if(enablePath2){
              positronPlusPos = 140;
            }
            else{
              positronPlusPos = 0;
            }
            for(i=lastPositronActive; i>0; i--){
              positron[i] = positron[i-1];
            }
            positron[0] = pathNumber-1;
          }
        }
        else{//Normal movement
          if(positron[0] > pathNumber-2){
            for(i=0; i<lastPositronActive; i++){
              positron[i] = positron[i+1];
            }
            lastPositronActive--;
            positronMinusPos = 0;
          }

          if(positron[lastPositronActive-1] >= 185){
            lastPositronActive++;
            if(enablePath2){
              positronPlusPos = 140;
            }
            else{
              positronPlusPos = 0;
            }
          }          
        }
      }
        
      if(enablePositronMovement2){
        if(enableSwapPolarity2){//Reverse movoment        
          //2nd path
          if(positron2[lastPositronActive2-1] == 0){
            lastPositronActive2--;
            positronMinusPos = 0;
          }

          if(pathNumber2 - positron2[0] > 185){
            lastPositronActive2++;
            positronPlusPos = 140;
            //positronPlusPos = 0;
            for(i=lastPositronActive2; i>0; i--){
              positron2[i] = positron2[i-1];
            }
            positron2[0] = pathNumber2-1;
          }
        }
        else{//normal movement
          //2nd path
          if(positron2[0] > pathNumber2-2){
            for(i=0; i<lastPositronActive2; i++){
              positron2[i] = positron2[i+1];
            }
            lastPositronActive2--;
            positronMinusPos = 0;
          }

          if(positron2[lastPositronActive2-1] >= 185){
            lastPositronActive2++;
            positronPlusPos = 140;
            //positronPlusPos = 0;
          }
        }
      }


      if(enablePositronMovement3){
        if(enableSwapPolarity3){//Reverse movoment        
          //3rd path
          if(positron3[lastPositronActive3-1] == 0){
            lastPositronActive3--;
            positronMinusPos = 0;
          }

          if(pathNumber3 - positron3[0] > 185){
            lastPositronActive3++;
            positronPlusPos = 140;
            //positronPlusPos = 0;
            for(i=lastPositronActive3; i>0; i--){
              positron3[i] = positron3[i-1];
            }
            positron3[0] = pathNumber3-1;
          }
        }
        else{//normal movement
          //3rd path
          if(positron3[0] > pathNumber3-2){
            for(i=0; i<lastPositronActive3; i++){
              positron3[i] = positron3[i+1];
            }
            lastPositronActive3--;
            positronMinusPos = 0;
          }

          if(positron3[lastPositronActive3-1] >= 185){
            lastPositronActive3++;
            positronPlusPos = 140;
            //positronPlusPos = 0;
          }
        }
      }
    }//if(enablePositrons){


    for(i = 0; i < MAGNETMAX; i++){//Rotating magnets
      if(enableMagnet[i] == 1){
        if(enableSwapMagnet[i]){
          drawMagnet(MagnetX[i], MagnetY[i], MagnetZ[i], -MagnetL[i], MagnetD[i], MagnetRot[i]);
        }
        else{
          drawMagnet(MagnetX[i], MagnetY[i], MagnetZ[i], MagnetL[i], MagnetD[i], MagnetRot[i]);
        }
      }//if(enableMagnet[0]){
    }

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 12: Arrows around coil ++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 12){
      
      //glEnable(GL_LIGHT0);
      glEnable(GL_LIGHT1);
      glEnable(GL_LIGHT2);

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGreen1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGreen1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGreen1);

      GLfloat radius = 3.0f;
      
      drawCylinder(radius, -0.50f, ArrowZ, radius, 0.50f, ArrowZ, 0.15f, 0.15f, 16, 1);
      drawCylinder(radius, -0.9f, ArrowZ, radius, -0.50f, ArrowZ, 0.01f, 0.35f, 16, 1);

      glDisable(GL_LIGHT0);
      glDisable(GL_LIGHT1);
      glDisable(GL_LIGHT2);

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlack1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlack1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlack1);

//      glRotatef(-rotX, 0.0f, 0.0f, 1.0f);  /* rotate on the X axis */
//      glBegin(GL_QUADS);
//        glColor3d(0,0,0);
//        glVertex3f(0.0f, radius - 1.5f, 0.0f);
//        glColor3d(0,0,0);
//        glVertex3f(0.0f, radius - 1.5f, 5.0f);
//        glColor3d(0,0,0);
//        glVertex3f(0.0f, radius + 1.5f, 5.0f);
//        glColor3d(0,0,0);
//        glVertex3f(0.0f, radius + 1.5f, 0.0f);
//      glEnd();

      drawCylinder(0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 5.0f, radius - 1.5f, radius - 1.5f, 16, 0);
      
      rotX+=1.5f;
      ArrowZ-=0.002f;
      
      if(animationFrames > 2000){
        done=True;
      }
      
    }//if(animation == 12){

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 11: Turning coil, missing step... +++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 11){



      if(animationStep == 5){//Wait for end
      
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = -0.1f;
          enableMotorRot = True;
          done = True;// !!!!!!!!!!!!!!!!!!!11 Exit !!!!!!!!!!!!!!!!!!!!
        }

      }

      if(animationStep == 4){//Stop Rotation
      
        if(MotorRotX < 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
          MotorRotX = 180.0f;
        }
      }

      if(animationStep == 3){//Wait for end
      
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = -0.1f;
          enableMotorRot = True;
        }

      }



      if(animationStep == 2){//Stop Rotation
      
        if(MotorRotX > 190.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
        }
      }


      if(animationStep == 1){//Tilt coil slightly
        enableBattery1 = True;
        enablePositrons = True;
        enablePositronMovement = True;
        enableSwapPolarity = False;


        MagnetX[0] = 0.0f;
        MagnetY[0] = 0.0f;
        MagnetZ[0] = -3.25f;
        MagnetD[0] = 1.1f;
        MagnetL[0] = 2.95f;
        MagnetRot[0] = 0.0f;
        enableSwapMagnet[0] = True;

        MagnetX[1] = 0.0f;
        MagnetY[1] = 0.0f;
        MagnetZ[1] = 3.25f;
        MagnetD[1] = 1.1f;
        MagnetL[1] = 2.95f;
        MagnetRot[1] = 0.0f;
        enableSwapMagnet[1] = True;

        MagnetX[2] = 0.0f;
        MagnetY[2] = 0.0f;
        MagnetZ[2] = -7.5f;
        MagnetD[2] = 2.6f;
        MagnetL[2] = 0.7f;
        MagnetRot[2] = 0.0f;

        MagnetX[3] = 0.0f;
        MagnetY[3] = 0.0f;
        MagnetZ[3] = 7.5f;
        MagnetD[3] = 2.6f;
        MagnetL[3] = 0.7f;
        MagnetRot[3] = 0.0f;
        
        enableMagnet[0] = True;
        enableMagnet[1] = True;
        enableMagnet[2] = 2;
        enableMagnet[3] = 2;
        
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.1f;
          enableMotorRot = True;
        }

      }




    }//if(animation == 11){



//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++ Animation 10: Commutation two coils with negative charges ++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 10){

      if(animationStep > 4){
        glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
        glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
        glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

        drawCylinder(Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 3.0f, Bat1Y1, Bat1Z1, 0.2001f, 0.2001f, 16, 1);
        drawCylinder(Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 3.0f, Bat1Y2, Bat1Z2, 0.2001f, 0.2001f, 16, 1);
      }

      //second coil with swapped Y/Z
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
      drawCylinder(Bat1X1 - 0.5f, Bat1Z1, Bat1Y1, 3.0f, Bat1Z1, Bat1Y1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Z2, Bat1Y2, 3.0f, Bat1Z2, Bat1Y2, 0.2001f, 0.2001f, 16, 1);


      if(animationStep == 8){
        if(animationFrames > 1600){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          done=True;// !!!!!!!!!!!!!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!
        }
      }


      if(animationStep == 7){
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          enableSwapMagnet[4] = False;
          enableSwapMagnet[5] = False;
          enableSwapPolarity2 = True;
          enableMotorRot = True;
          MotorRotSpeed = -0.324324324f;
        }
      }

      if(animationStep == 6){
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableMagnetsAll = True;
          enableMagnet[0] = True;
          enableMagnet[1] = True;
          enableSwapMagnet[0] = False;
          enableSwapMagnet[1] = False;

          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }

      if(animationStep == 5){//
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enablePositronMovement = True;
          enablePositronMovementAll = True;
          enablePositronsAll = True;
          //enablePositronMovement2 = True;

          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }



      if(animationStep == 4){//
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(paintPath < pathNumber){
          paintPath+=60;
          //printf("paintPath=%d\n", paintPath);
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enablePositrons = True;
          enableSwapPolarity = False;
          paintPath = 1;
          
          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }

      if(animationStep == 3){//
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames < 250){
          paintPath+=4;
          //printf("paintPath=%d\n", paintPath);
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.0f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
          
          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }


      if(animationStep == 2){//
        if(paintPath < 80){
          paintPath+=4;
          //printf("paintPath=%d\n", paintPath);
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.0f;
          rotXtarget = -90.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }


      if(animationStep == 1){//
          enablePositrons = False;
          enablePositronMovement = False;
          enablePositronMovement2 = False;
          enableMagnet[0] = False;
          enableMagnet[1] = False;
          
          
          enablePositronsAll = False;
          enablePositronMovementAll = False;
          enableMagnetsAll = False;
        if(animationFrames > 30){

          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;


          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }


  }//if(animation == 10){



//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++ Animation 09: Commutation three coils +++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 9){

      //drawCommutator(3, 0, 1.0f, 1.0f);

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

//      drawCylinder(Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 3.0f, Bat1Y1, Bat1Z1, 0.2001f, 0.2001f, 16, 1);
//      drawCylinder(Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 3.0f, Bat1Y2, Bat1Z2, 0.2001f, 0.2001f, 16, 1);

      //second coil with swapped Y/Z
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
//      drawCylinder(Bat1X1 - 0.5f, Bat1Z1, Bat1Y1, 3.0f, Bat1Z1, Bat1Y1, 0.2001f, 0.2001f, 16, 1);
//      drawCylinder(Bat1X2 - 0.5f, Bat1Z2, Bat1Y2, 3.0f, Bat1Z2, Bat1Y2, 0.2001f, 0.2001f, 16, 1);




      if(animationStep == 3){//Zoom to Commutator
      
        if(animationFrames == 185 * 4){
          enableMotorRot = True;
          MotorRotSpeed = 0.324324324f;
        }
        if(animationFrames > 185 * 8){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          done = True; // !!!!!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!
        }
      }


      if(animationStep == 2){//Stop rotation if two coils are enabled
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        GLfloat CommutatorAlpha = MotorRotX;
        while(CommutatorAlpha > 360.0f){
          CommutatorAlpha -= 360.0f;
        }
        while(CommutatorAlpha < 0.0f){
          CommutatorAlpha += 360.0f;
        }
        if(animationFrames > 185 * 4 && CommutatorAlpha > 246.0f && CommutatorAlpha < 252.0f){

          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableMotorRot = False;
          MotorRotSpeed = 0.0f;

        }
      }

      if(animationStep == 1){//Zoom out
        if(animationFrames > 185 * 4){

          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.0f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }


  }//if(animation == 9){



//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 08: Shortened windings ++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 8){

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightGolden1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightGolden1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightGolden1);
      
      for(i=0; i<scratchNumber; i++){
        drawCylinder(scratch[i][0], scratch[i][1], scratch[i][2], scratch[i][3], scratch[i][4], scratch[i][5], 0.201f, 0.201f, 16, 1);
      }

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightRed1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightRed1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightRed1);


      if(animationStep > 1){

          for(i=0; i<lastPositronActive; i++){
            drawSphere(path2[positron[i]][0], path2[positron[i]][1], path2[positron[i]][2], 0.3f, 20, 20, 0);
            positron[i]++;//Move positrons
          }

            if(positron[0] > pathNumber2-2){
              for(i=0; i<lastPositronActive; i++){
                positron[i] = positron[i+1];
              }
              lastPositronActive--;
            }

            if(positron[lastPositronActive-1] >= 92){
              lastPositronActive++;
            }

      }



      if(animationStep == 2){//Draw wire with moving positrons
        if(animationFrames > 400){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);

          done = True;// !!!!!!!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!
        }
      }

      if(animationStep == 1){//Draw "empty" wire
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
//          enablePositrons = True;
          enableBattery1 = True;
        }
      }

    }//if(animation == 8){

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++ Animation 07: Commutation two coils with wrong windings++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 7){

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

      drawCylinder(Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 3.0f, Bat1Y1, Bat1Z1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 3.0f, Bat1Y2, Bat1Z2, 0.2001f, 0.2001f, 16, 1);

      //second coil with swapped Y/Z
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
      drawCylinder(Bat1X1 - 0.5f, Bat1Z1, Bat1Y1, 3.0f, Bat1Z1, Bat1Y1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Z2, Bat1Y2, 3.0f, Bat1Z2, Bat1Y2, 0.2001f, 0.2001f, 16, 1);


      if(animationStep == 10){
        if(enableSwapPolarity2 && MotorRotSpeed < 0.0f){
          enableSwapMagnet[4] = True;
          enableSwapMagnet[5] = True;
          enableSwapPolarity2 = False;
        }        
        if(MotorRotX < 135.0f){
          MotorRotSpeed += 0.001f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          done = True;// !!!!!!!!!!!!!!!!!!!Exit !!!!!!!!!!!!!!!!!!!!!!!
        }
      }

      if(animationStep == 9){
        if(enableSwapPolarity && MotorRotSpeed > 0.0f){
          enableSwapMagnet[0] = True;
          enableSwapMagnet[1] = True;
          enableSwapPolarity = False;
        }        
        if(MotorRotX >= 135.0f){
          MotorRotSpeed -= 0.001f;
        }
        else{        
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 8){
        if(enableSwapPolarity2 && MotorRotSpeed < 0.0f){
          enableSwapMagnet[4] = True;
          enableSwapMagnet[5] = True;
          enableSwapPolarity2 = False;
        }
        if(MotorRotX < 135.0f){
          MotorRotSpeed += 0.001f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          //done = True;// !!!!!!!!!!!!!!!!!!!Exit !!!!!!!!!!!!!!!!!!!!!!!
        }
      }


      if(animationStep == 7){
        if(MotorRotX >= 135.0f){
          MotorRotSpeed -= 0.001f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 6){//Stop rotation
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableSwapMagnet[0] = True;
          enableSwapMagnet[1] = True;
          enableSwapPolarity = False;
        }
      }


      if(animationStep == 5){//Slow down rotation
        
        if(MotorRotX > 135.0f){
          MotorRotSpeed -= 0.001f;
        }
        else{
          MotorRotSpeed += 0.001f;
        }
        
        if(MotorRotSpeed < 0.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.0f;
        }
      }


      if(animationStep == 4){//Start rotation
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableMotorRot = True;
        }
      }

      if(animationStep == 3){//Swap windings of blue coil
        if(animationFrames > 185 * 2){
          if(paintPath2<pathNumber2){
            paintPath2+=60;
          }
          else{
            if(animationFrames == 185 * 4){
              animationStep++; printf("animationStep set to %d\n", animationStep);
              animationFrames = 0;
              paintPath2=0;
            }
          }
        }
      }


      if(animationStep == 2){//Swap windings of blue coil
        if(animationFrames > 185 * 2){

          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;


          //Swap Turn Z to -Z mirror invert path
          for(i=0; i<pathNumber2; i++){
            path2[i][2]=-path2[i][2];
            path2[i][5]=-path2[i][5];
          }
          

          for(i=0; i < maxPathCorners; i++){
            pathCorners2[i][2] = -pathCorners2[i][2];
          }

          //enableMotorRot = True;
          //MotorRotSpeed = 0.324324324f;
        }
      }

      if(animationStep == 1){//Paint coil blue
        if(animationFrames > 185 * 2){
          if(paintPath2 < pathNumber2){
            paintPath2 += 60;
          }
          else{
            if(animationFrames == 185 * 4){
              animationStep++; printf("animationStep set to %d\n", animationStep);
              animationFrames = 0;
              paintPath2=0;
            }
          }
        }
      }


  }//if(animation == 7){


//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 06: Commutation two coils +++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 6){

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

      drawCylinder(Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 3.0f, Bat1Y1, Bat1Z1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 3.0f, Bat1Y2, Bat1Z2, 0.2001f, 0.2001f, 16, 1);

      //second coil with swapped Y/Z
      glLightfv(GL_LIGHT1, GL_AMBIENT, lightBlue2);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightBlue2);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightBlue2);
      drawCylinder(Bat1X1 - 0.5f, Bat1Z1, Bat1Y1, 3.0f, Bat1Z1, Bat1Y1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Z2, Bat1Y2, 3.0f, Bat1Z2, Bat1Y2, 0.2001f, 0.2001f, 16, 1);


      if(animationStep == 17){//Rotate counterclockwise
        if(animationFrames > 1600){//To 1600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          done = True;// !!!!!!!!!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!
        }
      }

      if(animationStep == 16){//Swap motor polarity

        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
      
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = MotorRotSpeedOld;
        }
      }

      if(animationStep == 15){//Swap motor polarity

        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
      
        if(animationFrames > 180){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          //Swap motor direction
          if(isCommutatorContact){
            if(enableSwapPolarity){
              enableSwapPolarity = False;
            }
            else{
              enableSwapPolarity = True;
            }
            if(enableSwapMagnet[0]){
              enableSwapMagnet[0] = False;
            }
            else{
              enableSwapMagnet[0] = True;
            }
            if(enableSwapMagnet[1]){
              enableSwapMagnet[1] = False;
            }
            else{
              enableSwapMagnet[1] = True;
            }
          }
          if(isCommutatorContact2){
            if(enableSwapPolarity2){
              enableSwapPolarity2 = False;
            }
            else{
              enableSwapPolarity2 = True;
            }
            if(enableSwapMagnet[4]){
              enableSwapMagnet[4] = False;
            }
            else{
              enableSwapMagnet[4] = True;
            }
            if(enableSwapMagnet[5]){
              enableSwapMagnet[5] = False;
            }
            else{
              enableSwapMagnet[5] = True;
            }
          }
          //MotorRotSpeed = -MotorRotSpeed;
          MotorRotSpeedOld = -MotorRotSpeedOld;
          enableSwapMotor = True;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }


      if(animationStep == 14){//Stopped at 180 degrees
      
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.919999f;
          translateZtarget = 30.448929f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }


      if(animationStep == 13){//Stop at 180 degrees
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }
        if(alphaTemp > 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.0f;
          MotorRotX = 180.0f;
        }
      }

      if(animationStep == 12){//Stop at 180 degrees
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }
        if(alphaTemp < 10.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 11){//Stopped at 180 degrees
      
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MotorRotSpeed = MotorRotSpeedOld;
        }
      }


      if(animationStep == 10){//Stop at 180 degrees
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }
        if(alphaTemp > 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.0f;
          MotorRotX = 180.0f;
        }
      }


      if(animationStep == 9){//Total front view
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames >  185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = MotorRotSpeedOld;
        }
      }


      if(animationStep == 8){//Zoom to commutator
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames >  180){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }


      if(animationStep == 7){//Rotate for 45 degrees
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }      
        if(alphaTemp > 135.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.0f;
          MotorRotX = 135.0f;

          translateXtarget = 0.000000f;
          translateYtarget = 0.919999f;
          translateZtarget = 30.448929f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      if(animationStep == 6){//Total front view
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames >  185 * 4){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = MotorRotSpeedOld;

        }

      }


      if(animationStep == 5){//Total front view
      
        if(animationFrames > 185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 190.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }


      if(animationStep == 4){//Stop rotation at 90 degree angle
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }
        if(alphaTemp > 90.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          printf("alphaTemp=%lf\n", alphaTemp);
          animationFrames = 0;
          MotorRotSpeedOld = MotorRotSpeed;
          MotorRotSpeed = 0.0f;
          MotorRotX = 90.0f;
        }
      }

      if(animationStep == 3){//Close front view of commutator
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        GLfloat alphaTemp = MotorRotX;
        while(alphaTemp > 360.0f){
          alphaTemp -= 360.0f;
        }
        while(alphaTemp < 0.0f){
          alphaTemp += 360.0f;
        }
        if(alphaTemp < 90.0f && animationFrames > 600){//To 600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 2){//Close side view of commutator
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames > 200){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.919999f;
          translateZtarget = 30.448929f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }



      if(animationStep == 1){
        if(animationFrames > 1600){//To 1600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = -1.975799f;
          translateYtarget = 1.751199f;
          translateZtarget = 65.765976f;
          rotXtarget = -19.034998f;
          rotYtarget = 54.435013f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }





    }


//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 05: Commutation single coil +++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 5){

      glLightfv(GL_LIGHT1, GL_AMBIENT, lightWhite1);
      glLightfv(GL_LIGHT1, GL_DIFFUSE, lightWhite1);
      glLightfv(GL_LIGHT1, GL_SPECULAR, lightWhite1);

      drawCylinder(Bat1X1 - 0.5f, Bat1Y1, Bat1Z1, 3.0f, Bat1Y1, Bat1Z1, 0.2001f, 0.2001f, 16, 1);
      drawCylinder(Bat1X2 - 0.5f, Bat1Y2, Bat1Z2, 3.0f, Bat1Y2, Bat1Z2, 0.2001f, 0.2001f, 16, 1);




      if(animationStep == 12){//Zoom out
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 1600){//To 1600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          done = True;// !!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!!!!!!!
        }
      }
      if(animationStep == 11){//Zoom in
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 1600){//To 1600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 140.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }

      if(animationStep == 10){//Rotate countinuously
      
        if(animationFrames > 1600){//To 1600 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.790000f;
          translateZtarget = 27.150196f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      if(animationStep == 9){//Zoom out
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames >  185 * 3){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = True;
          MotorRotSpeed = MotorRotSpeedOld;
        }
      }



      if(animationStep == 8){//Zoom in
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames >  185 * 3){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 140.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }




      if(animationStep == 7){//Stop rotation while coil is energized
      
        if(animationFrames > 185 * 3){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 40.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }




      if(animationStep == 6){//Stop rotation 180 degrees later
      
        if(animationFrames > 100){

          GLfloat alphaTemp = MotorRotX;
          
          while(alphaTemp>360.0f){
            alphaTemp-=360.0f;
          }
          while(alphaTemp<0.0f){
            alphaTemp+=360.0f;
          }
          
          if(alphaTemp > 225.0f && alphaTemp < 230.0f){
            animationStep++; printf("animationStep set to %d\n", animationStep);
            animationFrames = 0;
            enableMotorRot = False;
            MotorRotSpeed = 0.0f;
          }
        }

      }

      if(animationStep == 5){//Zoom out
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames >  185 * 2){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableMotorRot = True;
          MotorRotSpeed = MotorRotSpeedOld;
        }
      }



      if(animationStep == 4){//Stop rotation while coil is energized at 45 degrees
      
        if(animationFrames > 185 * 3){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 140.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }

      if(animationStep == 3){//Move until contact
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 180){
          enableMotorRot = True;
          MotorRotSpeed = 0.324324324f;

          GLfloat alphaTemp = MotorRotX;
          
          while(alphaTemp>180.0f){
            alphaTemp-=180.0f;
          }
          while(alphaTemp<0.0f){
            alphaTemp+=180.0f;
          }
          
          if(alphaTemp > 45.0f && alphaTemp < 50.0f){
            animationStep++; printf("animationStep set to %d\n", animationStep);
            animationFrames = 0;
            MotorRotSpeedOld = MotorRotSpeed;
            MotorRotSpeed = 0.0f;
          }
        }
      }


      if(animationStep == 2){
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames > 180){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 40.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
                    
        }
      }


      if(animationStep == 1){
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;


          translateXtarget = -1.975799f;
          translateYtarget = 1.751199f;
          translateZtarget = 65.765976f;
          rotXtarget = -19.034998f;
          rotYtarget = 54.435013f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
          
        }
      }



    }

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 04: Turning coil ++++++++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 4){


      if(animationStep == 41){//Rotate coil to 540 degree
      
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep); printf("animation set to %d\n", animation);
          animationFrames = 0;

//          MotorRotSpeed =0.4f;
//          enableMotorRot = True;

          done = True;// !!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!!!!!
        }
      }

      if(animationStep == 40){//Rotate coil to 360 degree
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[0] = False;
          enableMagnet[1] = False;

        }
      }

      if(animationStep == 39){//Overshooting of rotation
        if( MotorRotSpeed > 0.0f){
          MotorRotSpeed -=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
        }
      }

      if(animationStep == 38){//Overshooting of rotation

        if(MotorRotX > 540.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 37){//Accelerate motor and rotate coil to 180 degree position
        if(MotorRotSpeed < 0.5f){
          MotorRotSpeed += 0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 36){//Rotate coil to 540 degree
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MotorRotSpeed = 0.0f;
          enableMotorRot = True;

        }
      }


      if(animationStep == 35){//Enable magnets
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableSwapMagnet[0] = True;
          enableSwapMagnet[1] = True;
          enableMagnet[0] = True;
          enableMagnet[1] = True;
        }
      }

      if(animationStep == 34){//Swap polatity
      
        if(animationFrames > 33){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          GLfloat temp;
          
          temp = Bat1X1;
          Bat1X1 = Bat1X2;
          Bat1X2 = temp;

          temp = Bat1Y1;
          Bat1Y1 = Bat1Y2;
          Bat1Y2 = temp;

          temp = Bat1Z1;
          Bat1Z1 = Bat1Z2;
          Bat1Z2 = temp;

          enableBattery1 = True;
          enablePositronMovement = True;
          enableSwapPolarity = False;
        }
      }

      if(animationStep == 33){//Rotate coil to 360 degree
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[0] = False;
          enableMagnet[1] = False;

        }
      }


      if(animationStep == 32){//Overshooting of rotation
        if( MotorRotSpeed > 0.0f){
          MotorRotSpeed -=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
        }
      }

      if(animationStep == 31){//Overshooting of rotation

        if(MotorRotX > 360.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 30){//Accelerate motor and rotate coil to 180 degree position
        if(MotorRotSpeed < 0.5f){
          MotorRotSpeed += 0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 29){//Rotate coil to 360 degree
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MotorRotSpeed = 0.0f;
          enableMotorRot = True;

        }
      }

      if(animationStep == 28){//Stop Rotation
      
        if(MotorRotX > 190.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
        }
      }

      if(animationStep == 27){//Rotate coil to 190 degree (manually)
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MotorRotSpeed = 0.1f;
          enableMotorRot = True;

        }
      }

      if(animationStep == 26){//Enable magnets
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableSwapMagnet[0] = False;
          enableSwapMagnet[1] = False;
          enableMagnet[0] = True;
          enableMagnet[1] = True;
        }
      }


      if(animationStep == 25){//Swap polatity
      
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          GLfloat temp;
          
          temp = Bat1X1;
          Bat1X1 = Bat1X2;
          Bat1X2 = temp;

          temp = Bat1Y1;
          Bat1Y1 = Bat1Y2;
          Bat1Y2 = temp;

          temp = Bat1Z1;
          Bat1Z1 = Bat1Z2;
          Bat1Z2 = temp;

          enableBattery1 = True;
          enablePositronMovement = True;
          enableSwapPolarity = True;
        }
      }

      if(animationStep == 24){//Turn off power
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[0] = False;
          enableMagnet[1] = False;
        }
      }

      if(animationStep == 23){//Rotation stopped

        if(MotorRotX > 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotX = 180.0f;
          enableMotorRot = False;
        }
      }

      if(animationStep == 22){//Overshooting of rotation
        if( MotorRotSpeed < 0.05f){
          MotorRotSpeed +=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 21){//Overshooting of rotation

        if(MotorRotX < 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 20){//Overshooting of rotation
        if( MotorRotSpeed > -0.1f){
          MotorRotSpeed -=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 19){//Overshooting of rotation

        if(MotorRotX > 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 18){//Overshooting of rotation
        if( MotorRotSpeed < 0.2f){
          MotorRotSpeed +=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 17){//Overshooting of rotation

        if(MotorRotX < 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 16){//Overshooting of rotation
        if( MotorRotSpeed > -0.3f){
          MotorRotSpeed -=0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 15){//Overshooting of rotation

        if(MotorRotX > 180.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 14){//Accelerate motor and rotate coil to 180 degree position
        if(MotorRotSpeed < 0.5f){
          MotorRotSpeed += 0.01f;
        }
        else{
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 13){//Start rotation of motor
      
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = True;
          MotorRotSpeed = 0.0f;
        }
      }


      if(animationStep == 12){//Stop Rotation
      
        if(MotorRotX > 10.0f){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMotorRot = False;
        }
      }




      if(animationStep == 11){//Tilt coil slightly
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MotorRotSpeed = 0.1f;
          enableMotorRot = True;
        }

      }



      if(animationStep == 10){//Draw external magnets and move to front
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = 95.000000f;
          rotXtarget = 0.000000f;
          rotYtarget = 90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      if(animationStep == 9){//Draw coils with magnet inside
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MagnetX[2] = 0.0f;
          MagnetY[2] = 0.0f;
          MagnetZ[2] = -7.5f;
          MagnetD[2] = 2.6f;
          MagnetL[2] = 0.7f;
          MagnetRot[2] = 0.0f;

          MagnetX[3] = 0.0f;
          MagnetY[3] = 0.0f;
          MagnetZ[3] = 7.5f;
          MagnetD[3] = 2.6f;
          MagnetL[3] = 0.7f;
          MagnetRot[3] = 0.0f;
          enableMagnet[2] = 2;
          enableSwapMagnet[2] = False;
          enableMagnet[3] = 2;
          enableSwapMagnet[3] = False;
        }
      }

      if(animationStep == 8){//Draw coils with magnet inside
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          enableAxis = True;
        }
      }

      if(animationStep == 7){//Draw coils with two magnets inside
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MagnetX[0] = 0.0f;
          MagnetY[0] = 0.0f;
          MagnetZ[0] = -3.25f;
          MagnetD[0] = 1.1f;
          MagnetL[0] = 2.95f;
          MagnetRot[0] = 0.0f;

          MagnetX[1] = 0.0f;
          MagnetY[1] = 0.0f;
          MagnetZ[1] = 3.25f;
          MagnetD[1] = 1.1f;
          MagnetL[1] = 2.95f;
          MagnetRot[1] = 0.0f;
          enableMagnet[0] = 1;
          enableSwapMagnet[0] = True;
          enableMagnet[1] = 1;
          enableSwapMagnet[1] = True;

        }
      }

      if(animationStep == 6){//Draw coils with single magnet inside
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          MagnetX[0] = 0.0f;
          MagnetY[0] = 0.0f;
          MagnetZ[0] = 0.0f;
          MagnetD[0] = 1.1f;
          MagnetL[0] = 6.00f;
          MagnetRot[0] = 0.0f;

          enableMagnet[1] = 0;

        }
      }


      if(animationStep == 5){//Draw wire with moving positrons
        if(animationFrames > 400){//To 400 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          MagnetX[0] = 0.0f;
          MagnetY[0] = 0.0f;
          MagnetZ[0] = -3.25f;
          MagnetD[0] = 1.1f;
          MagnetL[0] = 2.95f;
          MagnetRot[0] = 0.0f;

          MagnetX[1] = 0.0f;
          MagnetY[1] = 0.0f;
          MagnetZ[1] = 3.25f;
          MagnetD[1] = 1.1f;
          MagnetL[1] = 2.95f;
          MagnetRot[1] = 0.0f;
          enableMagnet[0] = 1;
          enableSwapMagnet[0] = True;
          enableMagnet[1] = 1;
          enableSwapMagnet[1] = True;
        }
      }

      if(animationStep == 4){//Draw wire with positrons
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enablePositronMovement = True;
        }
      }

      if(animationStep == 3){//Draw "empty" wire
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enablePositrons = True;
          enableBattery1 = True;
        }
      }

      if(animationStep == 2){//Draw "empty" wire with axis
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enableAxis = False;
        }
      }

      if(animationStep == 1){//Draw "empty" wire
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enableAxis = True;
        }
      }

    }//if(animation == 4){



//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 03: Blank windings ++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 3){


      if(animationStep > 1){

          for(i=0; i<lastPositronActive; i++){
            drawSphere(path2[positron[i]][0], path2[positron[i]][1], path2[positron[i]][2], 0.3f, 20, 20, 0);
            positron[i]++;//Move positrons
          }

            if(positron[0] > pathNumber2-2){
              for(i=0; i<lastPositronActive; i++){
                positron[i] = positron[i+1];
              }
              lastPositronActive--;
            }

            if(positron[lastPositronActive-1] >= 92){
              lastPositronActive++;
            }

      }


      if(animationStep == 5){//Rotate coil to initial position
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          done = True;// !!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!!!!!
        }
      }


      if(animationStep == 4){//Rotate coil to North
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.0f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.0f;
          rotZtarget = 0.0f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }




      if(animationStep == 3){//Rotate coil to South
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = 0.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }

      }


      if(animationStep == 2){//Draw wire with moving positrons
        if(animationFrames > 400){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      if(animationStep == 1){//Draw "empty" wire
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
//          enablePositrons = True;
          enableBattery1 = True;
        }
      }

    }//if(animation == 3){
    
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 02: Static coil reverse windings ++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 2){


      if(animationStep == 10){//Rotate coil to initial position
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          done = True;// !!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!!!!!
        }
      }


      if(animationStep == 9){//Rotate coil to North
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.0f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.0f;
          rotZtarget = 0.0f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }




      if(animationStep == 8){//Rotate coil to South
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = 0.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }

      }



      if(animationStep == 7){//Draw wire with magnet
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }


      if(animationStep == 6){//Draw wire with moving positrons
        if(animationFrames > 400){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enableMagnet[0] = 1;
          enableSwapMagnet[0] = True;
        }
      }

      if(animationStep == 5){//Draw wire with positrons
        if(animationFrames > 30){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          enablePositronMovement = True;
        }
      }



      if(animationStep == 4){//Draw white wire with red positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enablePositrons = True;
          enableBattery1 = True;
        }
      }
      
      
      if(animationStep == 3){//Paint coil
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(paintPath<pathNumber+120){
          paintPath+=4;
        }
        else{
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          paintPath = 0;
        }

      }
      

      if(animationStep == 2){//Rotate coil
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(paintPath<1400){
          paintPath+=4;
        }
        else{
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          
          translateXtarget = 0.000000f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }


      if(animationStep == 1){//Draw "empty" wire
//        animationStep = 15; // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        if(animationFrames > 30){
          paintPath+=4;
        }
        if(paintPath > 50){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }





    }//if(animation == 2){


//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//++++++++++++++++++ Animation 01: Static coil +++++++++++++++++++++++++
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    if(animation == 1){


      if(animationStep == 39){//Back to positive charges
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          done = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! Exit !!!!!!!!!!!!!!!!!!!!!!
        }

      }


      if(animationStep == 38){//Rotate coil to initial position
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBluePositrons = False;
          enableSwapPolarity = True;
        }

      }


      if(animationStep == 37){//Rotate coil to magnetic North
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.0f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.0f;
          rotZtarget = 0.0f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }




      if(animationStep == 36){//Move 2nd Magnet away from coil
        if(MagnetZ[1] < 20.0f){
          animationFrames = 0;
          MagnetZ[1]+=0.2f;
        }
        if(MagnetZ[1] > 20.0f){
          MagnetZ[1] = 20.0f;
        }
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          enableMagnet[1] = 0;
          
          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      if(animationStep == 35){//Move 2nd Magnet away from coil
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }



      if(animationStep == 34){//Move 2nd Magnet closer to left of coil
        if(MagnetZ[1] > 7.0f){
          animationFrames = 0;
          MagnetZ[1]-=0.1f;
        }
        if(MagnetZ[1] < 7.0f){
          MagnetZ[1] = 7.0f;
        }
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          GLfloat temp;
          
          temp = Bat1X1;
          Bat1X1 = Bat1X2;
          Bat1X2 = temp;

          temp = Bat1Y1;
          Bat1Y1 = Bat1Y2;
          Bat1Y2 = temp;

          temp = Bat1Z1;
          Bat1Z1 = Bat1Z2;
          Bat1Z2 = temp;

          enableSwapMagnet[0] = True;
          enableSwapPolarity = False;
        }
      }


      if(animationStep == 33){//Make 1st magnet visible
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 32){//Make 1st magnet visible
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMagnet[0] = 1;
        }
      }

      if(animationStep == 31){//Turn moving charges into negative particles
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = True;
          enablePositronMovement = True;
          enableSwapPolarity = True;
        }
      }

      if(animationStep == 30){//Move 2nd Magnet to left of coil
        if(MagnetZ[1] > 9.5f){
          animationFrames = 0;
          MagnetZ[1]-=0.3f;
        }
        if(MagnetZ[1] < 9.5f){
          MagnetZ[1] = 9.5f;
        }
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBluePositrons = True;
        }
      }

      if(animationStep == 29){//Make 2nd magnet visible
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MagnetZ[1] = 20.0f;
          enableMagnet[1] = 1;
        }
      }


      if(animationStep == 28){//Move 2nd Magnet closer to left of coil
        if(MagnetZ[1] > 7.0f){
          animationFrames = 0;
          MagnetZ[1]-=0.1f;
        }
        if(MagnetZ[1] < 7.0f){
          MagnetZ[1] = 7.0f;
        }
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[1] = 0;
          enableMagnet[0] = 0;
          enableSwapPolarity = True;
        }
      }



      if(animationStep == 27){//2nd Magnet to left of coil
        if(animationFrames > 400){
          enableSwapMagnet[0] = False;
          enableMagnet[0] = 1;
        }
        if(animationFrames > 800){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 26){//Move 2nd Magnet to left of coil
        if(MagnetZ[1] > 9.5f){
          animationFrames = 0;
          MagnetZ[1]-=0.3f;
        }
        if(MagnetZ[1] < 9.5f){
          MagnetZ[1] = 9.5f;
        }
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = True;
          enablePositronMovement = True;
          enableSwapPolarity = False;

          GLfloat temp;
          
          temp = Bat1X1;
          Bat1X1 = Bat1X2;
          Bat1X2 = temp;

          temp = Bat1Y1;
          Bat1Y1 = Bat1Y2;
          Bat1Y2 = temp;

          temp = Bat1Z1;
          Bat1Z1 = Bat1Z2;
          Bat1Z2 = temp;
        }
      }


      if(animationStep == 25){//Move 2nd Magnet away from coil
        if(MagnetZ[1] < 20.0f){
          animationFrames = 0;
          MagnetZ[1]+=0.2f;
        }
        if(MagnetZ[1] > 20.0f){
          MagnetZ[1] = 20.0f;
        }
        if(animationFrames > 40){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[0] = 0;
        }
      }


      if(animationStep == 24){//2nd Magnet to left of coil
        if(animationFrames > 400){
          enableMagnet[0] = 1;
        }
        if(animationFrames > 800){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }


      if(animationStep == 23){//Move 2nd Magnet to left of coil
        if(MagnetZ[1] > 7.5f){
          animationFrames = 0;
          MagnetZ[1]-=0.3f;
        }
        if(MagnetZ[1] < 7.5f){
          MagnetZ[1] = 7.5f;
        }
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBattery1 = True;
          enablePositronMovement = True;
        }
      }


      if(animationStep == 22){//Rotate coil to side position
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 380){//Turn coil off
          enableBattery1 = False;
          enablePositronMovement = False;
          enableMagnet[0] = 0;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMagnet[1] = 1;
          MagnetZ[1] = 20.0f;
          MagnetY[1] = 0.0f;
        }

      }


      if(animationStep == 21){//Rotate coil to South pole
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(animationFrames > 550){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 2.329998f;
          translateYtarget = 1.509999f;
          translateZtarget = -12.600008f;
          rotXtarget = 38.0f;
          rotYtarget = -90.0f;
          rotZtarget = 0.0f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;


        }

      }

      if(animationStep == 20){//Rotate coil to North pole
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 550){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = 0.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }


      if(animationStep == 19){//Insert Magnet
        if(MagnetZ[0] < 0.0f){
          animationFrames = 0;
          MagnetZ[0]+=0.3f;
        }
        if(MagnetZ[0] > 0.0f){
          MagnetZ[0] = 0.0f;
        }
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

          
        }
      }

      if(animationStep == 18){//Swap polarity
//enableMagnet[0] = 1;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!      
//enableSwapMagnet[0] = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!      
        if(animationFrames > 400){
          
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableSwapMagnet[0] = True;
          MagnetY[0] = 0.0f;
          MagnetZ[0] = -20.0f;
          enableMagnet[0] = 1;
          
        }
      }

      if(animationStep == 17){//Turn off elecric power
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          
          GLfloat temp;
          
          temp = Bat1X1;
          Bat1X1 = Bat1X2;
          Bat1X2 = temp;

          temp = Bat1Y1;
          Bat1Y1 = Bat1Y2;
          Bat1Y2 = temp;

          temp = Bat1Z1;
          Bat1Z1 = Bat1Z2;
          Bat1Z2 = temp;
          
          enableSwapPolarity = True;
          enablePositronMovement = True;
          enablePositrons = True;
          enableBattery1 = True;
          
        }
      }

      if(animationStep == 16){//Rotate coil to initial position
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MagnetZ[0] = 0.0f;
          MagnetY[0] = 30.0f;
          enableBattery1 = False;
          enablePositronMovement = False;
        }

      }

      if(animationStep == 15){//Facing magnetic South pole
        
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.0f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.0f;
          rotZtarget = 0.0f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }

      }

      if(animationStep == 14){//Rotate coil to magnetic south pole
      
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableMagnet[0] = 1;
        }
      }

      if(animationStep == 13){//Facing the magnetic North pole

        
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;

        }
      }

      if(animationStep == 12){//Rotate coil
      
        if(animationFrames == transitionFrames - 1){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }

      }



      if(animationStep == 11){//Draw wire with moving positrons
        //printf("animationStep=%d\n", animationStep);
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = 0.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }


      if(animationStep == 10){//Move magnet in coil
        if(MagnetZ[0] > 0.0f){
          MagnetZ[0]-=0.3f;
          animationFrames = 0;
        }
        if(MagnetZ[0] < 0.0f){
          MagnetZ[0] = 0.0f;
        }
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
        }
      }

      if(animationStep == 9){//Move positrons
        if(animationFrames > 400){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          MagnetX[0] = 0.0f;
          MagnetY[0] = 0.0f;
          MagnetZ[0] = 20.0f;
          enableMagnet[0] = 1;
        }
      }


      if(animationStep == 8){//Draw white wire with red positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enablePositronMovement = True;
          enableBattery1 = True;
        }
      }

      if(animationStep == 7){//Draw white wire with white positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableWhitePositrons = False;
        }
      }

      if(animationStep == 6){//Draw blue wire with red positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBlueWire = False;
          enableWhitePositrons = True;
        }
      }

      if(animationStep == 5){//Draw white wire with red positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          enableBlueWire = True;
        }
      }
      
      if(animationStep == 4){//Draw white wire with red positrons
        if(animationFrames > 30){
          animationStep++; printf("animationStep set to %d\n", animationStep);
          animationFrames = 0;
          //enableBluePositrons = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          //enableBlueWire = True;// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
          enablePositrons = True;
          //enableBattery1 = True;
        }
      }
      
      
      if(animationStep == 3){//Paint coil
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(paintPath<pathNumber+120){
          paintPath+=4;
        }
        else{
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          paintPath = 0;
        }

      }
      

      if(animationStep == 2){//Rotate coil
        if(animationFrames == transitionFrames - 1){
          translateX = translateXtarget;
          translateY = translateYtarget;
          translateZ = translateZtarget;
          rotX = rotXtarget;
          rotY = rotYtarget;
          rotZ = rotZtarget;

          translateXdiff = 0.0f;
          translateYdiff = 0.0f;
          translateZdiff = 0.0f;
          rotXdiff = 0.0f;
          rotYdiff = 0.0f;
          rotZdiff = 0.0f;
        }
        if(paintPath<1400){
          paintPath+=4;
        }
        else{
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);
          
          translateXtarget = 0.000000f;
          translateYtarget = 1.509999f;
          translateZtarget = -10.650002f;
          rotXtarget = 38.0f;
          rotYtarget = -90.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }

      }


      if(animationStep == 1){//Draw "empty" wire
//        animationStep = 15; // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        if(animationFrames > 30){
          paintPath+=4;
        }
        if(paintPath > 50){
          animationFrames = 0;
          animationStep++; printf("animationStep set to %d\n", animationStep);

          translateXtarget = 0.000000f;
          translateYtarget = 0.000000f;
          translateZtarget = -10.650002f;
          rotXtarget = 0.000000f;
          rotYtarget = -180.000000f;
          rotZtarget = 0.000000f;
          
          transitionFrames = 150.0f;
          
          translateXdiff = (translateXtarget - translateX) / transitionFrames;
          translateYdiff = (translateYtarget - translateY) / transitionFrames;
          translateZdiff = (translateZtarget - translateZ) / transitionFrames;
          rotXdiff = (rotXtarget - rotX) / transitionFrames;
          rotYdiff = (rotYtarget - rotY) / transitionFrames;
          rotZdiff = (rotZtarget - rotZ) / transitionFrames;
        }
      }

      
    }
    
    
//###########################################################################################
//############### Print text messages #######################################################
//###########################################################################################

    glEnable(GL_TEXTURE_2D);       /* Enable Texture Mapping */
    glEnable(GL_BLEND);
    glDisable(GL_LIGHTING);
    glEnable(GL_DEPTH_TEST);
    //glDisable(GL_BLEND);
    glLoadIdentity();
    glColor3f(1.0f, 1.0f, 0.0f);
    
    glFlush();
    glXSwapBuffers(GLWin.dpy, GLWin.win);

    if(firstStart > 0){
      firstStart--;
    }
    else{
      if(picNumber >= startPicNumber){// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        ScreenShot();
      }
      else{
        picNumber++;
      }
    }

    return True;    
}

/* function to release/destroy our resources and restoring the old desktop */
GLvoid killGLWindow(GLvoid){
  if (GLWin.ctx){
    if (!glXMakeCurrent(GLWin.dpy, None, NULL)){
      printf("Could not release drawing context.\n");
    }
    glXDestroyContext(GLWin.dpy, GLWin.ctx);
    GLWin.ctx = NULL;
  }
  /* switch back to original desktop resolution if we were in fs */
  if (GLWin.fs){
    XF86VidModeSwitchToMode(GLWin.dpy, GLWin.screen, &GLWin.deskMode);
    XF86VidModeSetViewPort(GLWin.dpy, GLWin.screen, 0, 0);
  }
  XCloseDisplay(GLWin.dpy);
}

/* this function creates our window and sets it up properly */
/* FIXME: bits is currently unused */
Bool createGLWindow(char* title, int width, int height, int bits, Bool fullscreenflag){
    XVisualInfo *vi;
    Colormap cmap;
    int dpyWidth, dpyHeight;
    int i;
    int glxMajorVersion, glxMinorVersion;
    int vidModeMajorVersion, vidModeMinorVersion;
    XF86VidModeModeInfo **modes;
    int modeNum;
    int bestMode;
    Atom wmDelete;
    Window winDummy;
    unsigned int borderDummy;
    
    GLWin.fs = fullscreenflag;
    /* set best mode to current */
    bestMode = 0;
    /* get a connection */
    GLWin.dpy = XOpenDisplay(0);
    GLWin.screen = DefaultScreen(GLWin.dpy);
    XF86VidModeQueryVersion(GLWin.dpy, &vidModeMajorVersion,
        &vidModeMinorVersion);
    printf("XF86VidModeExtension-Version %d.%d\n", vidModeMajorVersion,
        vidModeMinorVersion);
    XF86VidModeGetAllModeLines(GLWin.dpy, GLWin.screen, &modeNum, &modes);
    /* save desktop-resolution before switching modes */
    GLWin.deskMode = *modes[0];
    /* look for mode with requested resolution */
    for (i = 0; i < modeNum; i++)
    {
        if ((modes[i]->hdisplay == width) && (modes[i]->vdisplay == height))
        {
            bestMode = i;
        }
    }
    /* get an appropriate visual */
    vi = glXChooseVisual(GLWin.dpy, GLWin.screen, attrListDbl);
    if (vi == NULL)
    {
        vi = glXChooseVisual(GLWin.dpy, GLWin.screen, attrListSgl);
        printf("Only Singlebuffered Visual!\n");
    }
    else
    {
        printf("Got Doublebuffered Visual!\n");
    }
    glXQueryVersion(GLWin.dpy, &glxMajorVersion, &glxMinorVersion);
    printf("glX-Version %d.%d\n", glxMajorVersion, glxMinorVersion);
    /* create a GLX context */
    GLWin.ctx = glXCreateContext(GLWin.dpy, vi, 0, GL_TRUE);
    /* create a color map */
    cmap = XCreateColormap(GLWin.dpy, RootWindow(GLWin.dpy, vi->screen),
        vi->visual, AllocNone);
    GLWin.attr.colormap = cmap;
    GLWin.attr.border_pixel = 0;

    if (GLWin.fs)
    {
        XF86VidModeSwitchToMode(GLWin.dpy, GLWin.screen, modes[bestMode]);
        XF86VidModeSetViewPort(GLWin.dpy, GLWin.screen, 0, 0);
        dpyWidth = modes[bestMode]->hdisplay;
        dpyHeight = modes[bestMode]->vdisplay;
        printf("Resolution %dx%d\n", dpyWidth, dpyHeight);
        XFree(modes);
    
        /* create a fullscreen window */
        GLWin.attr.override_redirect = True;
        GLWin.attr.event_mask = ExposureMask | KeyPressMask | ButtonPressMask |
            StructureNotifyMask;
        GLWin.win = XCreateWindow(GLWin.dpy, RootWindow(GLWin.dpy, vi->screen),
            0, 0, dpyWidth, dpyHeight, 0, vi->depth, InputOutput, vi->visual,
            CWBorderPixel | CWColormap | CWEventMask | CWOverrideRedirect,
            &GLWin.attr);
        XWarpPointer(GLWin.dpy, None, GLWin.win, 0, 0, 0, 0, 0, 0);
		XMapRaised(GLWin.dpy, GLWin.win);
        XGrabKeyboard(GLWin.dpy, GLWin.win, True, GrabModeAsync,
            GrabModeAsync, CurrentTime);
        XGrabPointer(GLWin.dpy, GLWin.win, True, ButtonPressMask,
            GrabModeAsync, GrabModeAsync, GLWin.win, None, CurrentTime);
    }
    else
    {
        /* create a window in window mode*/
        GLWin.attr.event_mask = ExposureMask | KeyPressMask | ButtonPressMask |
            StructureNotifyMask;
        GLWin.win = XCreateWindow(GLWin.dpy, RootWindow(GLWin.dpy, vi->screen),
            0, 0, width, height, 0, vi->depth, InputOutput, vi->visual,
            CWBorderPixel | CWColormap | CWEventMask, &GLWin.attr);
        /* only set window title and handle wm_delete_events if in windowed mode */
        wmDelete = XInternAtom(GLWin.dpy, "WM_DELETE_WINDOW", True);
        XSetWMProtocols(GLWin.dpy, GLWin.win, &wmDelete, 1);
        XSetStandardProperties(GLWin.dpy, GLWin.win, title,
            title, None, NULL, 0, NULL);
        XMapRaised(GLWin.dpy, GLWin.win);
    }       
    /* connect the glx-context to the window */
    glXMakeCurrent(GLWin.dpy, GLWin.win, GLWin.ctx);
    XGetGeometry(GLWin.dpy, GLWin.win, &winDummy, &GLWin.x, &GLWin.y,
        &GLWin.width, &GLWin.height, &borderDummy, &GLWin.depth);
    printf("Depth %d\n", GLWin.depth);
    if (glXIsDirect(GLWin.dpy, GLWin.ctx)) 
        printf("Congrats, you have Direct Rendering!\n");
    else
        printf("Sorry, no Direct Rendering possible!\n");
    if (!initGL())
    {
        printf("Could not initialize OpenGL.\nAborting...\n");
        return False;
    }        
    return True;    
}


void keyPressed(KeySym key){
    switch (key){
        case XK_Escape:
            done = True;
            break;
        case XK_F1:
            killGLWindow();
            GLWin.fs = !GLWin.fs;
            createGLWindow("Electric field", 1280, 720, 24, GLWin.fs);
            break;
        case XK_F2:
            ScreenShot();
            break;
        case XK_space:
            if(animationPause == 0){
              animationPause = 1;
            }
            else{
              animationPause = 0;
            }
            break;
        case XK_u:
            translateY += 0.01f;
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_d:
            translateY -= 0.01f;
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_l:
            translateX -= 0.01f;
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_r:
            translateX += 0.01f;
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_plus:
            if(enableOrtho){
              translateZ -= 0.5f;
            }
            else{
              translateZ += 0.05f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_minus:
            if(enableOrtho){
              translateZ += 0.5f;
            }
            else{
              translateZ -= 0.05f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Left:
            if(enableOrtho){
              rotY += 0.25f;
            }
            else{
              rotY -= 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Right:
            if(enableOrtho){
              rotY -= 0.25f;
            }
            else{
              rotY += 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Up:
            if(enableOrtho){
              rotX += 0.25f;
            }
            else{
              rotX -= 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Down:
            if(enableOrtho){
              rotX -= 0.25f;
            }
            else{
              rotX += 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Page_Up:
            if(enableOrtho){
              rotZ -= 0.25f;
            }
            else{
              rotZ += 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
        case XK_Page_Down:
            if(enableOrtho){
              rotZ += 0.25f;
            }
            else{
              rotZ -= 0.25f;
            }
            printf("translateX=%lf, translateY=%lf, translateZ=%lf, rotX=%lf, rotY=%lf, rotZ=%lf\n", translateX, translateY, translateZ, rotX, rotY, rotZ);
            break;
    }
}

//######################################################################
//############## Main ##################################################
//######################################################################

int main(int argc, char **argv){
    XEvent event;
    KeySym key;
    GLfloat steps = 200.0;
    double x, y = 1;
    int i;
    int wrongArgs = 1;
    char commandLine[1000];
    
    animation = -1;
    //savePics = 1;
    startPicNumber = 1000000;
    slowDownMS = 0;

    MagnetX[0]=0.0f; MagnetY[0]=0.0f; MagnetZ[0]=0.0f; MagnetD[0] = 1.1f; MagnetL[0] = 6.0f, MagnetRot[0] = 0.0f;
    MagnetX[1]=0.0f; MagnetY[1]=0.0f; MagnetZ[1]=0.0f; MagnetD[1] = 2.6f; MagnetL[1] = 0.7f, MagnetRot[1] = 0.0f;;
    
    
    if (argc > 3){
      for (i = 1; i < argc; i++){
	      printf("argv[%d] = %s\n", i, argv[i]);
	    }
      if(strtol(argv[1], NULL, 10) > 0){
        animation = strtol(argv[1], NULL, 10);
        wrongArgs = 0;
      }

      slowDownMS = strtol(argv[2], NULL, 10);      

    }
    else{
      wrongArgs = 1;
    }
        
    if(wrongArgs > 0){
      printf("The command had no or too few arguments.\n");
      printf("Example of usage: Electrostatics 21 10 0\n");
      printf("First integer dials the animation sequence (1-29)\n");
      printf("Second integer sets slow down factor of animation in milliseconds(0-10000)\n");
      printf("If third integer is greater than 0, pictures are stored in folder PicSequence, starting with picture number given.\n");
      printf("\n");
      printf("When animation is running:\n");
      printf("Space: Stop/Start\n");
      printf("+: Zoom in\n");
      printf("-: Zoom out\n");
      printf("u: move up\n");
      printf("d: move down\n");
      printf("cursor: rotate\n");
      printf("up/down key: rotate\n");
      printf("F2: take snapshot\n");
      printf("F1: change between window mode and fullscreen\n");
      printf("\n");
      printf("www.HomoFaciens.de\n");
      exit(1);
    }
    
    startPicNumber = strtol(argv[3], NULL, 10);
    if(startPicNumber == 0){
      startPicNumber = 1000000;
    }
    else{    
      strcpy(SavePath, "./picsequence_");
      strcat(SavePath, argv[1]);
      strcpy(commandLine, "mkdir ");
      strcat(commandLine, SavePath);
      system(commandLine);
    }
    
    printf("animation set to %d\n",animation);
//    for(x=0; x<10;x++){
//      printf("atan2(%lf, %lf)=%lf,    atan2(%lf, %lf)=%lf\n", y, x, atan2(y, x), x, y, atan2(x, y));
//    }
        
    done = False;
    /* default to fullscreen */
    GLWin.fs = True;
    if (!createGLWindow("Electric field", 1920, 1080, 24, GLWin.fs)){
        done = True;
    }
    
    
//######################################################################
//Animation 01: Static coil
//######################################################################
    if(animation == 1){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      Bat1X1=4.0f, Bat1Y1=-radius, Bat1Z1=-0.5f;
      Bat1X2=4.0f, Bat1Y2=-radius, Bat1Z2=0.5f;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 0 = %d\n", pathNumber);
      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f;

      printf("pathNumber at corner 1 = %d\n", pathNumber);
      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      printf("pathNumber at corner 2 = %d\n", pathNumber);
      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      while(y < 0.0f - pathStep){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y-overlap;
        path[pathNumber][2] = z;
        y+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y+overlap;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      y=0.0f;
      

      xOld = radius * cos(alpha-overlap);
      yOld = radius * sin(alpha-overlap);
      zOld += pitch / (2.0f * PI / stepWidth);
      z = -windings * pitch / 2.0f;
      zOld = z;
      for(alpha=stepWidth/2.0f; alpha < windings * 2.0f * PI - PI/2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 3 = %d\n", pathNumber);
      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      printf("pathNumber at corner 4 = %d\n", pathNumber);
      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }


      translateX = 0.0f;
      translateY = 1.509999f;
      translateZ = -10.650002f;
      rotX = 38.0f;
      rotY = -90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }
    
//######################################################################
//Animation 02: Static coil with reverse windings
//######################################################################
    if(animation == 2){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      positron[0]=1;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      Bat1X1=4.0f, Bat1Y1=-radius, Bat1Z1=-0.5f;
      Bat1X2=4.0f, Bat1Y2=-radius, Bat1Z2=0.5f;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 0 = %d\n", pathNumber);
      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f;

      printf("pathNumber at corner 1 = %d\n", pathNumber);
      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > 0.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 0.0f;      

      xOld = radius * cos(alpha-overlap);
      yOld = radius * sin(alpha-overlap);
      zOld += pitch / (2.0f * PI / stepWidth);
      z = -windings * pitch / 2.0f;
      zOld = z;
      for(alpha=windings * 2.0f * PI - PI/2.0f - 0.01f; alpha > 0.0f ; alpha-=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha-overlap);
        y = radius * sin(alpha-overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }



      while(y > -radius + pathStep){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y+overlap;
        path[pathNumber][2] = z;
        y-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y-overlap;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      y=-radius;

      printf("pathNumber at corner 2 = %d\n", pathNumber);
      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 3 = %d\n", pathNumber);
      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      printf("pathNumber at corner 4 = %d\n", pathNumber);
      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }


      translateX = 0.0f;
      translateY = 1.509999f;
      translateZ = -10.650002f;
      rotX = 38.0f;
      rotY = -90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }

//######################################################################
//Animation 03: Coil with blank windings
//######################################################################
    if(animation == 3){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableGoldenWire = True;

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      positron[0]=1;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.35f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      Bat1X1=4.0f, Bat1Y1=-radius, Bat1Z1=-0.5f;
      Bat1X2=4.0f, Bat1Y2=-radius, Bat1Z2=0.5f;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        
        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > 0.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 0.0f;      

      GLfloat x2, y2, z2;
      
      x2 = x;
      y2 = y;
      z2 = z;

      alpha = 0.0f;
      xOld = radius * cos(alpha-overlap);
      yOld = radius * sin(alpha-overlap);
      zOld += pitch / (2.0f * PI / stepWidth);
      z = -windings * pitch / 2.0f;
      zOld = z;
      for(alpha=windings * 2.0f * PI - PI/2.0f - 0.01f; alpha > 0.0f ; alpha-=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha-overlap);
        y = radius * sin(alpha-overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      alpha=-PI/2.0f;
      GLfloat pitch2 = pitch * 77.0f;
      
      while(z2 < z){
        alpha+=stepWidth/6.0f;
        path2[pathNumber2][0] = x2;
        path2[pathNumber2][1] = y2;
        path2[pathNumber2][2] = z2;
        x2 = radius * cos(alpha-overlap);
        y2 = radius * sin(alpha-overlap);
        z2 += pitch2 / (2.0f * PI / stepWidth) / 6.0f;
        path2[pathNumber2][3] = x2;
        path2[pathNumber2][4] = y2;
        path2[pathNumber2][5] = z2;
        pathNumber2++;
        x2 = radius * cos(alpha);
        y2 = radius * sin(alpha);
      }


      while(y > -radius + pathStep){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y+overlap;
        path[pathNumber][2] = z;
        y-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y-overlap;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      y=-radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 3.0f;

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber2 - 45;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 92;
      }


      translateX = 0.0f;
      translateY = 1.509999f;
      translateZ = -10.650002f;
      rotX = 38.0f;
      rotY = -90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }//if(animation == 3){

//######################################################################
//Animation 04: Turning coil
//######################################################################
    if(animation == 4){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableAxis = False;
      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 0.5f;
      Bat1X1=4.0f, Bat1Y1=0.0f, Bat1Z1=-0.7f;
      Bat1X2=4.0f, Bat1Y2=0.0f, Bat1Z2=0.7f;
      maxPathCorners = 8;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }


      translateX = 0.0f;
      translateY = 0.96f;
      translateZ = 60.650002f;
      rotX = -46.0f;
      rotY = 85.25f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }//if(animation == 4){
    
//######################################################################
//Animation 05: Commutation single coil
//######################################################################
    if(animation == 5){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableAxis = True;
      positronPlusPos = 95;
      positronMinusPos = 95;
      enableCommutator = True;

      MagnetX[0] = 0.0f;
      MagnetY[0] = 0.0f;
      MagnetZ[0] = -3.25f;
      MagnetD[0] = 1.1f;
      MagnetL[0] = 2.95f;
      MagnetRot[0] = 0.0f;

      MagnetX[1] = 0.0f;
      MagnetY[1] = 0.0f;
      MagnetZ[1] = 3.25f;
      MagnetD[1] = 1.1f;
      MagnetL[1] = 2.95f;
      MagnetRot[1] = 0.0f;

      MagnetX[2] = 0.0f;
      MagnetY[2] = 0.0f;
      MagnetZ[2] = -7.5f;
      MagnetD[2] = 2.6f;
      MagnetL[2] = 0.7f;
      MagnetRot[2] = 0.0f;

      MagnetX[3] = 0.0f;
      MagnetY[3] = 0.0f;
      MagnetZ[3] = 7.5f;
      MagnetD[3] = 2.6f;
      MagnetL[3] = 0.7f;
      MagnetRot[3] = 0.0f;

      enableSwapMagnet[0] = True;
      enableSwapMagnet[1] = True;
      enableMagnet[2] = 2;
      enableSwapMagnet[2] = False;
      enableMagnet[3] = 2;
      enableSwapMagnet[3] = False;

      Bat1X1=5.7f, Bat1Y1=0.0f, Bat1Z1=-0.4f;
      Bat1X2=5.7f, Bat1Y2=0.0f, Bat1Z2=0.4f;

      Bat2X1 = Bat1X1 + 0.5f;
      Bat2X2 = Bat1X2 + 0.5f;
      Bat2Y1 = -2.5f;
      Bat2Y2 = -2.5f;
      Bat2Z1 = -4.0f;
      Bat2Z2 = 4.0f;
      enableBattery2 = True;

      enableMotorRot = False;
      MotorRotSpeed = 0.0f;
      positronStep = 2;


      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 0.5f;
      maxPathCorners = 8;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;

      printf("pathNumber=%d\n", pathNumber);

      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }

      translateX = 0.000000f;
      translateY = 0.000000f;
      translateZ = 85.000000f;
      rotX = 0.000000f;
      rotY = 90.000000f;
      rotZ = 0.000000f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }//if(animation == 5){
    
//######################################################################
//Animation 06: Commutation double coil
//######################################################################
    if(animation == 6){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableSwapPolarity2 = True;
      enableMagnet[0] = 0;
      enableAxis = True;
      positronPlusPos = 165;
      positronMinusPos = 95;
      positronStep = 2;
      enableCommutator = True;
      enablePath2 = True;

      MagnetX[0] = 0.0f;
      MagnetY[0] = 0.0f;
      MagnetZ[0] = -5.1f;
      MagnetD[0] = 1.1f;
      MagnetL[0] = 2.95f;
      MagnetRot[0] = 0.0f;

      MagnetX[1] = 0.0f;
      MagnetY[1] = 0.0f;
      MagnetZ[1] = 5.1f;
      MagnetD[1] = 1.1f;
      MagnetL[1] = 2.95f;
      MagnetRot[1] = 0.0f;

      MagnetX[2] = 0.0f;
      MagnetY[2] = 0.0f;
      MagnetZ[2] = -9.5f;
      MagnetD[2] = 2.6f;
      MagnetL[2] = 0.7f;
      MagnetRot[2] = 0.0f;

      MagnetX[3] = 0.0f;
      MagnetY[3] = 0.0f;
      MagnetZ[3] = 9.5f;
      MagnetD[3] = 2.6f;
      MagnetL[3] = 0.7f;
      MagnetRot[3] = 0.0f;

      MagnetX[4] = 0.0f;
      MagnetY[4] = 0.0f;
      MagnetZ[4] = -5.25f;
      MagnetD[4] = 1.1f;
      MagnetL[4] = 2.95f;
      MagnetRot[4] = 90.0f;

      MagnetX[5] = 0.0f;
      MagnetY[5] = 0.0f;
      MagnetZ[5] = 5.25f;
      MagnetD[5] = 1.1f;
      MagnetL[5] = 2.95f;
      MagnetRot[5] = 90.0f;

      enableSwapMagnet[0] = True;
      enableSwapMagnet[1] = True;
      enableMagnet[2] = 2;
      enableSwapMagnet[2] = False;
      enableMagnet[3] = 2;
      enableSwapMagnet[3] = False;

      enableSwapMagnet[4] = True;
      enableSwapMagnet[5] = True;

      Bat1X1=5.7f, Bat1Y1=0.0f, Bat1Z1=-0.4f;
      Bat1X2=5.7f, Bat1Y2=0.0f, Bat1Z2=0.4f;

      Bat2X1 = Bat1X1 + 0.5f;
      Bat2X2 = Bat1X2 + 0.5f;
      Bat2Y1 = -2.5f;
      Bat2Y2 = -2.5f;
      Bat2Z1 = -4.0f;
      Bat2Z2 = 4.0f;
      enableBattery2 = True;

      enableMotorRot = True;
      MotorRotSpeed = 0.324324324f;


      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 2.5f;
      maxPathCorners = 8;

      
      //First coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;

      printf("pathNumber=%d\n", pathNumber);

      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }






      //Second coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      pathCorners2[0][0] = x;
      pathCorners2[0][1] = y;
      pathCorners2[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners2[1][0] = x;
      pathCorners2[1][1] = y;
      pathCorners2[1][2] = z;


      while(x > radius){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = radius;

      pathCorners2[2][0] = x;
      pathCorners2[2][1] = y;
      pathCorners2[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 4.0f; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners2[3][0] = x;
      pathCorners2[3][1] = y;
      pathCorners2[3][2] = z;



      while(z < coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z-overlap;
        z+=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z+overlap;
        pathNumber2++;
      }
      
      z = coilGap;

      pathCorners2[4][0] = x;
      pathCorners2[4][1] = y;
      pathCorners2[4][2] = z;

      for(alpha=windings * PI - PI / 4.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners2[5][0] = x;
      pathCorners2[5][1] = y;
      pathCorners2[5][2] = z;


      while(x < 3.0f){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      pathCorners2[6][0] = x;
      pathCorners2[6][1] = y;
      pathCorners2[6][2] = z;

      while(z > Bat1Z2){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = Bat1Z2;

      pathCorners2[7][0] = x;
      pathCorners2[7][1] = y;
      pathCorners2[7][2] = z;


      while(x < Bat1X2){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = Bat1X2;

      printf("pathNumber2=%d\n", pathNumber2);
      
      int PositronPosition2 = pathNumber - 90;
      PositronPosition2 = pathNumber2 - 90;
      lastPositronActive2 = 0;
      while(PositronPosition2 > 0){
        positron2[lastPositronActive2] = PositronPosition2;
        lastPositronActive2++;
        PositronPosition2 -= 185;
      }


      //Swap Y/Z to rotate 2nd path for 90 degrees
      GLfloat GLtemp;
      for(i=0; i<pathNumber2; i++){
        GLtemp = path2[i][1];
        path2[i][1]=path2[i][2];
        path2[i][2]=GLtemp;

        GLtemp = path2[i][4];
        path2[i][4]=path2[i][5];
        path2[i][5]=GLtemp;
      }
      

      for(i=0; i < maxPathCorners; i++){
        GLtemp = pathCorners2[i][1];
        pathCorners2[i][1] = pathCorners2[i][2];
        pathCorners2[i][2] = GLtemp;
      }

      //Swap Turn Z to -Z mirror invert path
      for(i=0; i<pathNumber2; i++){
        path2[i][2]=-path2[i][2];
        path2[i][5]=-path2[i][5];
      }
      

      for(i=0; i < maxPathCorners; i++){
        pathCorners2[i][2] = -pathCorners2[i][2];
      }


      translateX = 0.000000f;
      translateY = 0.000000f;
      translateZ = 190.000000f;
      rotX = 0.000000f;
      rotY = 90.000000f;
      rotZ = 0.000000f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;

    
    }//if(animation == 6){

//######################################################################
//Animation 07: Commutation double coil with wrong windings
//######################################################################
    if(animation == 7){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableSwapPolarity2 = False;
      enableMagnet[0] = 0;
      enableAxis = True;
      positronPlusPos = 165;
      positronMinusPos = 95;
      positronStep = 2;
      enableCommutator = True;
      enablePath2 = True;

      MagnetX[0] = 0.0f;
      MagnetY[0] = 0.0f;
      MagnetZ[0] = -5.1f;
      MagnetD[0] = 1.1f;
      MagnetL[0] = 2.95f;
      MagnetRot[0] = 0.0f;

      MagnetX[1] = 0.0f;
      MagnetY[1] = 0.0f;
      MagnetZ[1] = 5.1f;
      MagnetD[1] = 1.1f;
      MagnetL[1] = 2.95f;
      MagnetRot[1] = 0.0f;

      MagnetX[2] = 0.0f;
      MagnetY[2] = 0.0f;
      MagnetZ[2] = -9.5f;
      MagnetD[2] = 2.6f;
      MagnetL[2] = 0.7f;
      MagnetRot[2] = 0.0f;

      MagnetX[3] = 0.0f;
      MagnetY[3] = 0.0f;
      MagnetZ[3] = 9.5f;
      MagnetD[3] = 2.6f;
      MagnetL[3] = 0.7f;
      MagnetRot[3] = 0.0f;

      MagnetX[4] = 0.0f;
      MagnetY[4] = 0.0f;
      MagnetZ[4] = -5.25f;
      MagnetD[4] = 1.1f;
      MagnetL[4] = 2.95f;
      MagnetRot[4] = 90.0f;

      MagnetX[5] = 0.0f;
      MagnetY[5] = 0.0f;
      MagnetZ[5] = 5.25f;
      MagnetD[5] = 1.1f;
      MagnetL[5] = 2.95f;
      MagnetRot[5] = 90.0f;

      enableSwapMagnet[0] = True;
      enableSwapMagnet[1] = True;
      enableMagnet[2] = 2;
      enableSwapMagnet[2] = False;
      enableMagnet[3] = 2;
      enableSwapMagnet[3] = False;

      enableSwapMagnet[4] = True;
      enableSwapMagnet[5] = True;

      Bat1X1=5.7f, Bat1Y1=0.0f, Bat1Z1=-0.4f;
      Bat1X2=5.7f, Bat1Y2=0.0f, Bat1Z2=0.4f;

      Bat2X1 = Bat1X1 + 0.5f;
      Bat2X2 = Bat1X2 + 0.5f;
      Bat2Y1 = -2.5f;
      Bat2Y2 = -2.5f;
      Bat2Z1 = -4.0f;
      Bat2Z2 = 4.0f;
      enableBattery2 = True;

      MotorRotX = 90.0f;
      enableMotorRot = False;
      MotorRotSpeed = 0.0f;


      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 2.5f;
      maxPathCorners = 8;

      
      //First coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;

      printf("pathNumber=%d\n", pathNumber);

      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }






      //Second coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      printf("pathNumber2 at corner 0 = %d\n", pathNumber2);
      pathCorners2[0][0] = x;
      pathCorners2[0][1] = y;
      pathCorners2[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      printf("pathNumber2 at corner 1 = %d\n", pathNumber2);
      pathCorners2[1][0] = x;
      pathCorners2[1][1] = y;
      pathCorners2[1][2] = z;


      while(x > radius){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = radius;

      printf("pathNumber2 at corner 2 = %d\n", pathNumber2);
      pathCorners2[2][0] = x;
      pathCorners2[2][1] = y;
      pathCorners2[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 4.0f; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      printf("pathNumber2 at corner 3 = %d\n", pathNumber2);
      pathCorners2[3][0] = x;
      pathCorners2[3][1] = y;
      pathCorners2[3][2] = z;



      while(z < coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z-overlap;
        z+=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z+overlap;
        pathNumber2++;
      }
      
      z = coilGap;

      printf("pathNumber2 at corner 4 = %d\n", pathNumber2);
      pathCorners2[4][0] = x;
      pathCorners2[4][1] = y;
      pathCorners2[4][2] = z;

      for(alpha=windings * PI - PI / 4.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      printf("pathNumber2 at corner 5 = %d\n", pathNumber2);
      pathCorners2[5][0] = x;
      pathCorners2[5][1] = y;
      pathCorners2[5][2] = z;


      while(x < 3.0f){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      printf("pathNumber2 at corner 6 = %d\n", pathNumber2);
      pathCorners2[6][0] = x;
      pathCorners2[6][1] = y;
      pathCorners2[6][2] = z;

      while(z > Bat1Z2){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = Bat1Z2;

      printf("pathNumber2 at corner 7 = %d\n", pathNumber2);
      pathCorners2[7][0] = x;
      pathCorners2[7][1] = y;
      pathCorners2[7][2] = z;


      while(x < Bat1X2){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = Bat1X2;

      printf("pathNumber2=%d\n", pathNumber2);
      
      int PositronPosition2 = pathNumber - 90;
      PositronPosition2 = pathNumber2 - 90;
      lastPositronActive2 = 0;
      while(PositronPosition2 > 0){
        positron2[lastPositronActive2] = PositronPosition2;
        lastPositronActive2++;
        PositronPosition2 -= 185;
      }


      //Swap Y/Z to rotate 2nd path for 90 degrees
      GLfloat GLtemp;
      for(i=0; i<pathNumber2; i++){
        GLtemp = path2[i][1];
        path2[i][1]=path2[i][2];
        path2[i][2]=GLtemp;

        GLtemp = path2[i][4];
        path2[i][4]=path2[i][5];
        path2[i][5]=GLtemp;
      }
      

      for(i=0; i < maxPathCorners; i++){
        GLtemp = pathCorners2[i][1];
        pathCorners2[i][1] = pathCorners2[i][2];
        pathCorners2[i][2] = GLtemp;
      }

      //Swap Turn Z to -Z mirror invert path
      for(i=0; i<pathNumber2; i++){
        path2[i][2]=-path2[i][2];
        path2[i][5]=-path2[i][5];
      }
      

      for(i=0; i < maxPathCorners; i++){
        pathCorners2[i][2] = -pathCorners2[i][2];
      }


      translateX = 0.000000f;
      translateY = 0.000000f;
      translateZ = 190.000000f;
      rotX = 0.000000f;
      rotY = 90.000000f;
      rotZ = 0.000000f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;

    
    }//if(animation == 7){
    
//######################################################################
//Animation 08: Coil with shortened windings
//######################################################################
    if(animation == 8){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableGoldenWire = False;

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      positron[0]=1;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.35f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      Bat1X1=4.0f, Bat1Y1=-radius, Bat1Z1=-0.5f;
      Bat1X2=4.0f, Bat1Y2=-radius, Bat1Z2=0.5f;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        
        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > 0.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 0.0f;      

      GLfloat x2, y2, z2;
      
      x2 = x;
      y2 = y;
      z2 = z;

      alpha = 0.0f;
      z = -windings * pitch / 2.0f;
      zOld = z;
      for(alpha=windings * 2.0f * PI - PI/2.0f - 0.01f; alpha > 0.0f ; alpha-=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha-overlap);
        y = radius * sin(alpha-overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      alpha = 0.0f;
      z2 = -windings * pitch / 2.0f;
      for(alpha=windings * 2.0f * PI - PI/2.0f - 0.01f; alpha > 13.0f * 2.0f * PI + PI/4.0f - 0.01f ; alpha-=stepWidth/2.0f){
        path2[pathNumber2][0] = x2;
        path2[pathNumber2][1] = y2;
        path2[pathNumber2][2] = z2;
        x2 = radius * cos(alpha-overlap);
        y2 = radius * sin(alpha-overlap);
        z2 += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x2;
        path2[pathNumber2][4] = y2;
        path2[pathNumber2][5] = z2;
        pathNumber2++;
        x2 = radius * cos(alpha);
        y2 = radius * sin(alpha);
      }

      //Scratch
      for(scratchNumber=0; scratchNumber < 6; scratchNumber++){
        scratch[scratchNumber][0]=x2-0.07f;
        scratch[scratchNumber][1]=y2 + 0.07f;
        scratch[scratchNumber][2]=z2 + scratchNumber * 0.35f;

        scratch[scratchNumber][3]=x2+0.07f;
        scratch[scratchNumber][4]=y2 - 0.07f;
        scratch[scratchNumber][5]=z2 + scratchNumber * 0.35f;
      }
      for(i=0; i<70; i++){
        path2[pathNumber2][0] = x2;
        path2[pathNumber2][1] = y2;
        path2[pathNumber2][2] = z2+overlap;
        z2+=pathStep;
        path2[pathNumber2][3] = x2;
        path2[pathNumber2][4] = y2;
        path2[pathNumber2][5] = z2-overlap;
        pathNumber2++;
      }

      for(alpha=8.0f * 2.0f * PI + PI/4.0f - 0.01f; alpha > 0.0f ; alpha-=stepWidth/2.0f){
        path2[pathNumber2][0] = x2;
        path2[pathNumber2][1] = y2;
        path2[pathNumber2][2] = z2;
        x2 = radius * cos(alpha-overlap);
        y2 = radius * sin(alpha-overlap);
        z2 += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x2;
        path2[pathNumber2][4] = y2;
        path2[pathNumber2][5] = z2;
        pathNumber2++;
        x2 = radius * cos(alpha);
        y2 = radius * sin(alpha);
      }


      while(y > -radius + pathStep){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y+overlap;
        path[pathNumber][2] = z;
        y-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y-overlap;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }


      y=-radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = 3.0f;

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;

        path2[pathNumber2][0] = path[pathNumber][0];
        path2[pathNumber2][1] = path[pathNumber][1];
        path2[pathNumber2][2] = path[pathNumber][2];
        path2[pathNumber2][3] = path[pathNumber][3];
        path2[pathNumber2][4] = path[pathNumber][4];
        path2[pathNumber2][5] = path[pathNumber][5];
        pathNumber2++;

        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber2 - 45;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }


      translateX = 0.0f;
      translateY = 1.509999f;
      translateZ = -10.650002f;
      rotX = 38.0f;
      rotY = -90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
    
    }//if(animation == 8){


//######################################################################
//Animation 09: Commutation three coils
//######################################################################
    if(animation == 9){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableSwapPolarity2 = False;
      enableMagnet[0] = 0;
      enableAxis = True;
      positronPlusPos = 165;
      positronMinusPos = 95;
      positronStep = 2;
      enableCommutator = True;
      enablePath2 = True;
      enablePath3 = True;

      MagnetX[0] = 0.0f;
      MagnetY[0] = 0.0f;
      MagnetZ[0] = -5.1f;
      MagnetD[0] = 1.1f;
      MagnetL[0] = 2.95f;
      MagnetRot[0] = 0.0f;

      MagnetX[1] = 0.0f;
      MagnetY[1] = 0.0f;
      MagnetZ[1] = -5.0f;
      MagnetD[1] = 1.1f;
      MagnetL[1] = 2.95f;
      MagnetRot[1] = 120.0f;
      

      MagnetX[2] = 0.0f;
      MagnetY[2] = 0.0f;
      MagnetZ[2] = -9.5f;
      MagnetD[2] = 2.6f;
      MagnetL[2] = 0.7f;
      MagnetRot[2] = 0.0f;

      MagnetX[3] = 0.0f;
      MagnetY[3] = 0.0f;
      MagnetZ[3] = 9.5f;
      MagnetD[3] = 2.6f;
      MagnetL[3] = 0.7f;
      MagnetRot[3] = 0.0f;

      MagnetX[4] = 0.0f;
      MagnetY[4] = 0.0f;
      MagnetZ[4] = -5.10f;
      MagnetD[4] = 1.1f;
      MagnetL[4] = 2.95f;
      MagnetRot[4] = 240.0f;


      MagnetX[5] = 0.0f;
      MagnetY[5] = 0.0f;
      MagnetZ[5] = 5.25f;
      MagnetD[5] = 1.1f;
      MagnetL[5] = 2.95f;
      MagnetRot[5] = 90.0f;

      enableSwapMagnet[0] = True;
      enableSwapMagnet[1] = True;
      enableMagnet[2] = 2;
      enableSwapMagnet[2] = False;
      enableMagnet[3] = 2;
      enableSwapMagnet[3] = False;

      enableSwapMagnet[4] = True;
      enableSwapMagnet[5] = True;

      Bat1X1=5.7f, Bat1Y1=0.0f, Bat1Z1=-0.6f;
      Bat1X2=5.7f, Bat1Y2=-0.61f, Bat1Z2=-0.1f;

      Bat2X1 = Bat1X1 + 0.5f;
      Bat2X2 = Bat1X2 + 0.5f;
      Bat2Y1 = -2.5f;
      Bat2Y2 = -2.5f;
      Bat2Z1 = -4.0f;
      Bat2Z2 = 4.0f;
      enableBattery2 = True;

      MotorRotX = 0.0f;
      enableMotorRot = True;
      MotorRotSpeed = 0.324324324f;


      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 2.5f;
      maxPathCorners = 6;

      
      //First coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;


      while(z < Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;


      while(y < Bat1Y2 ){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y-overlap;
        path[pathNumber][2] = z;
        y+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y+overlap;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      y = Bat1Y2;
      
      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;

      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;

      printf("pathNumber=%d\n", pathNumber);

      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }



      


      //Second coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      pathCorners2[0][0] = x;
      pathCorners2[0][1] = y;
      pathCorners2[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners2[1][0] = x;
      pathCorners2[1][1] = y;
      pathCorners2[1][2] = z;


      while(x > radius){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = radius;

      pathCorners2[2][0] = x;
      pathCorners2[2][1] = y;
      pathCorners2[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 4.0f; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners2[3][0] = x;
      pathCorners2[3][1] = y;
      pathCorners2[3][2] = z;



      while(z < Bat1Z2){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z-overlap;
        z+=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z+overlap;
        pathNumber2++;
      }
      
      z = Bat1Z2;

      pathCorners2[4][0] = x;
      pathCorners2[4][1] = y;
      pathCorners2[4][2] = z;


      while(y < Bat1Y2 ){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y-overlap;
        path2[pathNumber2][2] = z;
        y+=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y+overlap;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      y = Bat1Y2;

      pathCorners2[5][0] = x;
      pathCorners2[5][1] = y;
      pathCorners2[5][2] = z;


      while(x < Bat1X2){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = Bat1X2;

      printf("pathNumber2=%d\n", pathNumber2);
      
      int PositronPosition2 = pathNumber - 90;
      PositronPosition2 = pathNumber2 - 90;
      lastPositronActive2 = 0;
      while(PositronPosition2 > 0){
        positron2[lastPositronActive2] = PositronPosition2;
        lastPositronActive2++;
        PositronPosition2 -= 185;
      }


      //Rotate 2nd path for 60 degrees
      GLfloat yRot, zRot;
      for(i=0; i<pathNumber2; i++){
        
        yRot = path2[i][1] * cos(PI * 2.0f / 3.0f) - path2[i][2] * sin(PI * 2.0f / 3.0f);
        zRot = path2[i][1] * sin(PI * 2.0f / 3.0f) + path2[i][2] * cos(PI * 2.0f / 3.0f);
        path2[i][1] = yRot;
        path2[i][2] = zRot;

        yRot = path2[i][4] * cos(PI * 2.0f / 3.0f) - path2[i][5] * sin(PI * 2.0f / 3.0f);
        zRot = path2[i][4] * sin(PI * 2.0f / 3.0f) + path2[i][5] * cos(PI * 2.0f / 3.0f);
        path2[i][4] = yRot;
        path2[i][5] = zRot;
      }
      

      for(i=0; i < maxPathCorners; i++){
        yRot = pathCorners2[i][1] * cos(PI * 2.0f / 3.0f) - pathCorners2[i][2] * sin(PI * 2.0f / 3.0f);
        zRot = pathCorners2[i][1] * sin(PI * 2.0f / 3.0f) + pathCorners2[i][2] * cos(PI * 2.0f / 3.0f);
        pathCorners2[i][1] = yRot;
        pathCorners2[i][2] = zRot;
      }



      //Third coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path3[pathNumber3][0] = x+overlap;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z;
        x-=pathStep;
        path3[pathNumber3][3] = x-overlap;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z;
        pathNumber3++;
      }

      x = 3.0f;

      pathCorners3[0][0] = x;
      pathCorners3[0][1] = y;
      pathCorners3[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path3[pathNumber3][0] = x;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z+overlap;
        z-=pathStep;
        path3[pathNumber3][3] = x;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z-overlap;
        pathNumber3++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners3[1][0] = x;
      pathCorners3[1][1] = y;
      pathCorners3[1][2] = z;


      while(x > radius){
        path3[pathNumber3][0] = x+overlap;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z;
        x-=pathStep;
        path3[pathNumber3][3] = x-overlap;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z;
        pathNumber3++;
      }

      x = radius;

      pathCorners3[2][0] = x;
      pathCorners3[2][1] = y;
      pathCorners3[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 4.0f; alpha+=stepWidth/2.0f){
        path3[pathNumber3][0] = x;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path3[pathNumber3][3] = x;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z;
        pathNumber3++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners3[3][0] = x;
      pathCorners3[3][1] = y;
      pathCorners3[3][2] = z;



      while(z < Bat1Z2){
        path3[pathNumber3][0] = x;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z-overlap;
        z+=pathStep;
        path3[pathNumber3][3] = x;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z+overlap;
        pathNumber3++;
      }
      
      z = Bat1Z2;

      pathCorners3[4][0] = x;
      pathCorners3[4][1] = y;
      pathCorners3[4][2] = z;


      while(y < Bat1Y2 ){
        path3[pathNumber3][0] = x;
        path3[pathNumber3][1] = y-overlap;
        path3[pathNumber3][2] = z;
        y+=pathStep;
        path3[pathNumber3][3] = x;
        path3[pathNumber3][4] = y+overlap;
        path3[pathNumber3][5] = z;
        pathNumber3++;
      }

      y = Bat1Y2;

      pathCorners3[5][0] = x;
      pathCorners3[5][1] = y;
      pathCorners3[5][2] = z;


      while(x < Bat1X2){
        path3[pathNumber3][0] = x-overlap;
        path3[pathNumber3][1] = y;
        path3[pathNumber3][2] = z;
        x+=pathStep;
        path3[pathNumber3][3] = x+overlap;
        path3[pathNumber3][4] = y;
        path3[pathNumber3][5] = z;
        pathNumber3++;
      }

      x = Bat1X2;

      printf("pathNumber3=%d\n", pathNumber3);
      
      int PositronPosition3 = pathNumber - 90;
      PositronPosition3 = pathNumber3 - 90;
      lastPositronActive3 = 0;
      while(PositronPosition3 > 0){
        positron3[lastPositronActive3] = PositronPosition3;
        lastPositronActive3++;
        PositronPosition3 -= 185;
      }


      //Rotate 3rd path for 120 degrees
      for(i=0; i<pathNumber3; i++){
        
        yRot = path3[i][1] * cos(PI * 4.0f / 3.0f) - path3[i][2] * sin(PI * 4.0f / 3.0f);
        zRot = path3[i][1] * sin(PI * 4.0f / 3.0f) + path3[i][2] * cos(PI * 4.0f / 3.0f);
        path3[i][1] = yRot;
        path3[i][2] = zRot;

        yRot = path3[i][4] * cos(PI * 4.0f / 3.0f) - path3[i][5] * sin(PI * 4.0f / 3.0f);
        zRot = path3[i][4] * sin(PI * 4.0f / 3.0f) + path3[i][5] * cos(PI * 4.0f / 3.0f);
        path3[i][4] = yRot;
        path3[i][5] = zRot;
      }
      

      for(i=0; i < maxPathCorners; i++){
        yRot = pathCorners3[i][1] * cos(PI * 4.0f / 3.0f) - pathCorners3[i][2] * sin(PI * 4.0f / 3.0f);
        zRot = pathCorners3[i][1] * sin(PI * 4.0f / 3.0f) + pathCorners3[i][2] * cos(PI * 4.0f / 3.0f);
        pathCorners3[i][1] = yRot;
        pathCorners3[i][2] = zRot;
      }


      translateX = -1.379999f;
      translateY = 0.000000f;
      translateZ = 81.393372f;
      rotX = 0.000000f;
      rotY = 49.750000f;
      rotZ = 0.000000f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;

    
    }//if(animation == 9){

//######################################################################
//Animation 10: Commutation with negative charges
//######################################################################
    if(animation == 10){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;
      paintPath = 1;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableSwapPolarity2 = False;
      enableMagnet[0] = 0;
      enableAxis = True;
      positronPlusPos = 165;
      positronMinusPos = 95;
      positronStep = 2;
      enableCommutator = True;
      enablePath2 = True;
      enableBluePositrons = True;

      MagnetX[0] = 0.0f;
      MagnetY[0] = 0.0f;
      MagnetZ[0] = -5.1f;
      MagnetD[0] = 1.1f;
      MagnetL[0] = 2.95f;
      MagnetRot[0] = 0.0f;

      MagnetX[1] = 0.0f;
      MagnetY[1] = 0.0f;
      MagnetZ[1] = 5.1f;
      MagnetD[1] = 1.1f;
      MagnetL[1] = 2.95f;
      MagnetRot[1] = 0.0f;

      MagnetX[2] = 0.0f;
      MagnetY[2] = 0.0f;
      MagnetZ[2] = -9.5f;
      MagnetD[2] = 2.6f;
      MagnetL[2] = 0.7f;
      MagnetRot[2] = 0.0f;

      MagnetX[3] = 0.0f;
      MagnetY[3] = 0.0f;
      MagnetZ[3] = 9.5f;
      MagnetD[3] = 2.6f;
      MagnetL[3] = 0.7f;
      MagnetRot[3] = 0.0f;

      MagnetX[4] = 0.0f;
      MagnetY[4] = 0.0f;
      MagnetZ[4] = -5.25f;
      MagnetD[4] = 1.1f;
      MagnetL[4] = 2.95f;
      MagnetRot[4] = 90.0f;

      MagnetX[5] = 0.0f;
      MagnetY[5] = 0.0f;
      MagnetZ[5] = 5.25f;
      MagnetD[5] = 1.1f;
      MagnetL[5] = 2.95f;
      MagnetRot[5] = 90.0f;

      enableSwapMagnet[0] = True;
      enableSwapMagnet[1] = True;
      enableMagnet[2] = 2;
      enableSwapMagnet[2] = False;
      enableMagnet[3] = 2;
      enableSwapMagnet[3] = False;

      enableSwapMagnet[4] = True;
      enableSwapMagnet[5] = True;

      Bat1X1=5.7f, Bat1Y1=0.0f, Bat1Z1=-0.4f;
      Bat1X2=5.7f, Bat1Y2=0.0f, Bat1Z2=0.4f;

      Bat2X1 = Bat1X1 + 0.5f;
      Bat2X2 = Bat1X2 + 0.5f;
      Bat2Y1 = -2.5f;
      Bat2Y2 = -2.5f;
      Bat2Z1 = -4.0f;
      Bat2Z2 = 4.0f;
      enableBattery2 = True;

      MotorRotX = 90.0f;
      enableMotorRot = False;
      MotorRotSpeed = 0.0f;


      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 2.5f;
      maxPathCorners = 8;

      
      //First coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 0 = %d\n", pathNumber);
      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      printf("pathNumber at corner 1 = %d\n", pathNumber);
      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      printf("pathNumber at corner 2 = %d\n", pathNumber);
      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      printf("pathNumber at corner 3 = %d\n", pathNumber);
      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      printf("pathNumber at corner 4 = %d\n", pathNumber);
      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      printf("pathNumber at corner 5 = %d\n", pathNumber);
      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      printf("pathNumber at corner 6 = %d\n", pathNumber);
      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      printf("pathNumber at corner 7 = %d\n", pathNumber);
      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;

      printf("pathNumber=%d\n", pathNumber);

      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }






      //Second coil
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      pathCorners2[0][0] = x;
      pathCorners2[0][1] = y;
      pathCorners2[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners2[1][0] = x;
      pathCorners2[1][1] = y;
      pathCorners2[1][2] = z;


      while(x > radius){
        path2[pathNumber2][0] = x+overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x-=pathStep;
        path2[pathNumber2][3] = x-overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = radius;

      pathCorners2[2][0] = x;
      pathCorners2[2][1] = y;
      pathCorners2[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 4.0f; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners2[3][0] = x;
      pathCorners2[3][1] = y;
      pathCorners2[3][2] = z;



      while(z < coilGap){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z-overlap;
        z+=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z+overlap;
        pathNumber2++;
      }
      
      z = coilGap;

      pathCorners2[4][0] = x;
      pathCorners2[4][1] = y;
      pathCorners2[4][2] = z;

      for(alpha=windings * PI - PI / 4.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x = radius * cos(alpha+overlap*3.5f);
        y = radius * sin(alpha+overlap*3.5f);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners2[5][0] = x;
      pathCorners2[5][1] = y;
      pathCorners2[5][2] = z;


      while(x < 3.0f){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = 3.0f;

      pathCorners2[6][0] = x;
      pathCorners2[6][1] = y;
      pathCorners2[6][2] = z;

      while(z > Bat1Z2){
        path2[pathNumber2][0] = x;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z+overlap;
        z-=pathStep;
        path2[pathNumber2][3] = x;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z-overlap;
        pathNumber2++;
      }
      
      z = Bat1Z2;

      pathCorners2[7][0] = x;
      pathCorners2[7][1] = y;
      pathCorners2[7][2] = z;


      while(x < Bat1X2){
        path2[pathNumber2][0] = x-overlap;
        path2[pathNumber2][1] = y;
        path2[pathNumber2][2] = z;
        x+=pathStep;
        path2[pathNumber2][3] = x+overlap;
        path2[pathNumber2][4] = y;
        path2[pathNumber2][5] = z;
        pathNumber2++;
      }

      x = Bat1X2;

      printf("pathNumber2=%d\n", pathNumber2);
      
      int PositronPosition2 = pathNumber - 90;
      PositronPosition2 = pathNumber2 - 90;
      lastPositronActive2 = 0;
      while(PositronPosition2 > 0){
        positron2[lastPositronActive2] = PositronPosition2;
        lastPositronActive2++;
        PositronPosition2 -= 185;
      }


      //Swap Y/Z to rotate 2nd path for 90 degrees
      GLfloat GLtemp;
      for(i=0; i<pathNumber2; i++){
        GLtemp = path2[i][1];
        path2[i][1]=path2[i][2];
        path2[i][2]=GLtemp;

        GLtemp = path2[i][4];
        path2[i][4]=path2[i][5];
        path2[i][5]=GLtemp;
      }
      

      for(i=0; i < maxPathCorners; i++){
        GLtemp = pathCorners2[i][1];
        pathCorners2[i][1] = pathCorners2[i][2];
        pathCorners2[i][2] = GLtemp;
      }

      //Swap Turn Z to -Z mirror invert path
      for(i=0; i<pathNumber2; i++){
        path2[i][2]=-path2[i][2];
        path2[i][5]=-path2[i][5];
      }
      

      for(i=0; i < maxPathCorners; i++){
        pathCorners2[i][2] = -pathCorners2[i][2];
      }


      translateX = 0.000000f;
      translateY = 0.000000f;
      translateZ = 190.000000f;
      rotX = 0.000000f;
      rotY = 90.000000f;
      rotZ = 0.000000f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;

    
    }//if(animation == 10){

//######################################################################
//Animation 11: Turning coil missing step...
//######################################################################
    if(animation == 11){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableAxis = False;
      enableOrtho = True;
      resizeGLScene(1920, 1080);

      for(i=0; i<100; i++){
        positron[i]=0;
      }

      lastPositronActive = 0;
      
      radius=2.0f;
      GLfloat x=0.0f, y=0.0f, z=0.0f, xOld=0.0f, yOld=0.0f, zOld=0.0f;
      GLfloat stepWidth = 0.02f;
      GLfloat pitch = 0.5f;
      GLfloat overlap = 0.0025f;
      GLfloat alpha=0.0f;
      GLfloat windings = 20.0f;
      GLfloat coilGap = 0.5f;
      Bat1X1=4.0f, Bat1Y1=0.0f, Bat1Z1=-0.7f;
      Bat1X2=4.0f, Bat1Y2=0.0f, Bat1Z2=0.7f;
      maxPathCorners = 8;

      
      x = Bat1X1;
      y = Bat1Y1;
      z = Bat1Z1;
      
      while(x > 3.0f){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[0][0] = x;
      pathCorners[0][1] = y;
      pathCorners[0][2] = z;

      while(z > -windings * pitch / 2.0f - coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = -windings * pitch / 2.0f - coilGap;

      pathCorners[1][0] = x;
      pathCorners[1][1] = y;
      pathCorners[1][2] = z;


      while(x > radius){
        path[pathNumber][0] = x+overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x-=pathStep;
        path[pathNumber][3] = x-overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = radius;

      pathCorners[2][0] = x;
      pathCorners[2][1] = y;
      pathCorners[2][2] = z;


      for(alpha=stepWidth/2.0f; alpha < windings * PI - PI / 2.0f; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }

      pathCorners[3][0] = x;
      pathCorners[3][1] = y;
      pathCorners[3][2] = z;



      while(z < coilGap){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z-overlap;
        z+=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z+overlap;
        pathNumber++;
      }
      
      z = coilGap;

      pathCorners[4][0] = x;
      pathCorners[4][1] = y;
      pathCorners[4][2] = z;

      for(alpha=windings * PI - PI / 2.0f; alpha < windings * 2.0f * PI; alpha+=stepWidth/2.0f){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x = radius * cos(alpha+overlap);
        y = radius * sin(alpha+overlap);
        z += pitch / (2.0f * PI / stepWidth) / 2.0f;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
        x = radius * cos(alpha);
        y = radius * sin(alpha);
      }


      pathCorners[5][0] = x;
      pathCorners[5][1] = y;
      pathCorners[5][2] = z;


      while(x < 3.0f){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = 3.0f;

      pathCorners[6][0] = x;
      pathCorners[6][1] = y;
      pathCorners[6][2] = z;

      while(z > Bat1Z2){
        path[pathNumber][0] = x;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z+overlap;
        z-=pathStep;
        path[pathNumber][3] = x;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z-overlap;
        pathNumber++;
      }
      
      z = Bat1Z2;

      pathCorners[7][0] = x;
      pathCorners[7][1] = y;
      pathCorners[7][2] = z;


      while(x < Bat1X2){
        path[pathNumber][0] = x-overlap;
        path[pathNumber][1] = y;
        path[pathNumber][2] = z;
        x+=pathStep;
        path[pathNumber][3] = x+overlap;
        path[pathNumber][4] = y;
        path[pathNumber][5] = z;
        pathNumber++;
      }

      x = Bat1X2;


      int PositronPosition = pathNumber - 90;
      lastPositronActive = 0;
      while(PositronPosition > 0){
        positron[lastPositronActive] = PositronPosition;
        lastPositronActive++;
        PositronPosition -= 185;
      }


      translateX = 0.0f;
      translateY = 0.0f;
      translateZ = 95.0f;
      rotX = 0.0f;
      rotY = 90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
      
      MotorRotX = 180.0f;
/*    
      GLfloat temp;
      
      temp = Bat1X1;
      Bat1X1 = Bat1X2;
      Bat1X2 = temp;

      temp = Bat1Y1;
      Bat1Y1 = Bat1Y2;
      Bat1Y2 = temp;

      temp = Bat1Z1;
      Bat1Z1 = Bat1Z2;
      Bat1Z2 = temp;
*/    
    }//if(animation == 11){

//######################################################################
//Animation 12: Arrows around coil
//######################################################################
    if(animation == 12){
      animationStep = 1;
      animationFrames = 0;
      enableLight2 = 0;
      enableLight3 = 0;
      maxPathCorners = -1;

      enableBattery1 = False;
      enablePositrons = False;
      enablePositronMovement = False;
      enableMagnet[0] = 0;
      enableAxis = False;
      enableOrtho = True;
      resizeGLScene(1920, 1080);

      translateX = 0.0f;
      translateY = 0.0f;
      translateZ = 95.0f;
      rotX = 0.0f;
      rotY = 90.0f;
      rotZ = 0.0f;

      translateXdiff = 0.0f;
      translateYdiff = 0.0f;
      translateZdiff = 0.0f;
      rotXdiff = 0.0f;
      rotYdiff = 0.0f;
      rotZdiff = 0.0f;
      
      MotorRotX = 180.0f;

  }//if(animation == 12){



    i=0;
    /* wait for events*/ 
    while (!done){
        /* handle the events in the queue */
        while (XPending(GLWin.dpy) > 0){
            XNextEvent(GLWin.dpy, &event);
            switch (event.type){
                case Expose:
	                if (event.xexpose.count != 0)
	                    break;
                    drawGLScene();
                    break;
                case ConfigureNotify:
                /* call resizeGLScene only if our window-size changed */
                    if ((event.xconfigure.width != GLWin.width) || (event.xconfigure.height != GLWin.height)){
                        GLWin.width = event.xconfigure.width;
                        GLWin.height = event.xconfigure.height;
                        printf("Resize event\n");
                        resizeGLScene(event.xconfigure.width,
                            event.xconfigure.height);
                    }
                    break;
                /* exit in case of a mouse button press */
                case ButtonPress:     
                    //done = True;
                    break;
                case KeyPress:
                    key = XLookupKeysym(&event.xkey, 0);
                    keyPressed(key);
                    break;
                case ClientMessage:    
                    if (*XGetAtomName(GLWin.dpy, event.xclient.message_type) == *"WM_PROTOCOLS"){
                        printf("Exiting sanely...\n");
                        done = True;
                    }
                    break;
                default:
                    break;
            }
        }
        //for(i=0; i<10; i++){
          drawGLScene();
        //}
    }
    killGLWindow();
    return 0;
}
